@@ -7,40 +7,60 @@ import json
 import re
 import socket
 import time
-import warnings
+from enum import StrEnum
 from html.parser import HTMLParser
-from os import path
 from queue import PriorityQueue, Queue
 from threading import Thread
 from typing import TYPE_CHECKING, NamedTuple, cast
-from urllib.parse import unquote, urlparse, urlsplit, urlunparse
+from urllib.parse import quote, unquote, urlparse, urlsplit, urlunparse
 
 from docutils import nodes
-from requests.exceptions import ConnectionError, HTTPError, SSLError, TooManyRedirects
+from requests.exceptions import (
+    ConnectionError,  # NoQA: A004
+    HTTPError,
+    SSLError,
+    TooManyRedirects,
+)
 from requests.exceptions import Timeout as RequestTimeout
 
+from sphinx._cli.util.colour import darkgray, darkgreen, purple, red, turquoise
 from sphinx.builders.dummy import DummyBuilder
-from sphinx.deprecation import RemovedInSphinx80Warning
 from sphinx.locale import __
 from sphinx.transforms.post_transforms import SphinxPostTransform
-from sphinx.util import encode_uri, logging, requests
-from sphinx.util.console import darkgray, darkgreen, purple, red, turquoise
+from sphinx.util import logging, requests
+from sphinx.util._uri import encode_uri
 from sphinx.util.http_date import rfc1123_to_epoch
 from sphinx.util.nodes import get_node_line
 
 if TYPE_CHECKING:
-    from collections.abc import Iterator
-    from typing import Any, Callable
+    from collections.abc import Callable, Iterator
+    from typing import Any, Literal, TypeAlias
 
     from requests import Response
 
     from sphinx.application import Sphinx
     from sphinx.config import Config
+    from sphinx.util._pathlib import _StrPath
     from sphinx.util.typing import ExtensionMetadata
 
+    _URIProperties: TypeAlias = tuple['_Status', str, int]
+
+
+class _Status(StrEnum):
+    BROKEN = 'broken'
+    IGNORED = 'ignored'
+    RATE_LIMITED = 'rate-limited'
+    REDIRECTED = 'redirected'
+    TIMEOUT = 'timeout'
+    UNCHECKED = 'unchecked'
+    UNKNOWN = 'unknown'
+    WORKING = 'working'
+
+
 logger = logging.getLogger(__name__)
 
-uri_re = re.compile('([a-z]+:)?//')  # matches to foo:// and // (a protocol relative URL)
+# matches to foo:// and // (a protocol relative URL)
+uri_re = re.compile('([a-z]+:)?//')
 
 DEFAULT_REQUEST_HEADERS = {
     'Accept': 'text/html,application/xhtml+xml;q=0.9,*/*;q=0.8',
@@ -51,13 +71,10 @@ DEFAULT_DELAY = 60.0
 
 
 class CheckExternalLinksBuilder(DummyBuilder):
-    """
-    Checks for broken external links.
-    """
+    """Checks for broken external links."""
 
     name = 'linkcheck'
-    epilog = __('Look for any errors in the above output or in '
-                '%(outdir)s/output.txt')
+    epilog = __('Look for any errors in the above output or in %(outdir)s/output.txt')
 
     def init(self) -> None:
         self.broken_hyperlinks = 0
@@ -66,33 +83,16 @@ class CheckExternalLinksBuilder(DummyBuilder):
         # set a timeout for non-responding servers
         socket.setdefaulttimeout(5.0)
 
-        if not self.config.linkcheck_allow_unauthorized:
-            deprecation_msg = (
-                "The default value for 'linkcheck_allow_unauthorized' will change "
-                "from `True` in Sphinx 7.3+ to `False`, meaning that HTTP 401 "
-                "unauthorized responses will be reported as broken by default. "
-                "See https://github.com/sphinx-doc/sphinx/issues/11433 for details."
-            )
-            warnings.warn(deprecation_msg, RemovedInSphinx80Warning, stacklevel=1)
-
-        if self.config.linkcheck_report_timeouts_as_broken:
-            deprecation_msg = (
-                "The default value for 'linkcheck_report_timeouts_as_broken' will change "
-                'to False in Sphinx 8, meaning that request timeouts '
-                "will be reported with a new 'timeout' status, instead of as 'broken'. "
-                'This is intended to provide more detail as to the failure mode. '
-                'See https://github.com/sphinx-doc/sphinx/issues/11868 for details.'
-            )
-            warnings.warn(deprecation_msg, RemovedInSphinx80Warning, stacklevel=1)
-
     def finish(self) -> None:
         checker = HyperlinkAvailabilityChecker(self.config)
         logger.info('')
 
-        output_text = path.join(self.outdir, 'output.txt')
-        output_json = path.join(self.outdir, 'output.json')
-        with open(output_text, 'w', encoding='utf-8') as self.txt_outfile, \
-             open(output_json, 'w', encoding='utf-8') as self.json_outfile:
+        output_text = self.outdir / 'output.txt'
+        output_json = self.outdir / 'output.json'
+        with (
+            open(output_text, 'w', encoding='utf-8') as self.txt_outfile,
+            open(output_json, 'w', encoding='utf-8') as self.json_outfile,
+        ):
             for result in checker.check(self.hyperlinks):
                 self.process_result(result)
 
@@ -101,75 +101,108 @@ class CheckExternalLinksBuilder(DummyBuilder):
 
     def process_result(self, result: CheckResult) -> None:
         filename = self.env.doc2path(result.docname, False)
+        res_uri = result.uri
 
-        linkstat = {'filename': filename, 'lineno': result.lineno,
-                    'status': result.status, 'code': result.code, 'uri': result.uri,
-                    'info': result.message}
+        linkstat: dict[str, str | int | _Status] = {
+            'filename': str(filename),
+            'lineno': result.lineno,
+            'status': result.status,
+            'code': result.code,
+            'uri': res_uri,
+            'info': result.message,
+        }
         self.write_linkstat(linkstat)
 
-        if result.status == 'unchecked':
-            return
-        if result.status == 'working' and result.message == 'old':
-            return
-        if result.lineno:
+        if result.lineno and result.status != _Status.UNCHECKED:
+            # unchecked links are not logged
             logger.info('(%16s: line %4d) ', result.docname, result.lineno, nonl=True)
-        if result.status == 'ignored':
-            if result.message:
-                logger.info(darkgray('-ignored- ') + result.uri + ': ' + result.message)
-            else:
-                logger.info(darkgray('-ignored- ') + result.uri)
-        elif result.status == 'local':
-            logger.info(darkgray('-local-   ') + result.uri)
-            self.write_entry('local', result.docname, filename, result.lineno, result.uri)
-        elif result.status == 'working':
-            logger.info(darkgreen('ok        ') + result.uri + result.message)
-        elif result.status == 'timeout':
-            if self.app.quiet or self.app.warningiserror:
-                logger.warning('timeout   ' + result.uri + result.message,
-                               location=(result.docname, result.lineno))
-            else:
-                logger.info(red('timeout   ') + result.uri + red(' - ' + result.message))
-            self.write_entry('timeout', result.docname, filename, result.lineno,
-                             result.uri + ': ' + result.message)
-            self.timed_out_hyperlinks += 1
-        elif result.status == 'broken':
-            if self.app.quiet or self.app.warningiserror:
-                logger.warning(__('broken link: %s (%s)'), result.uri, result.message,
-                               location=(result.docname, result.lineno))
-            else:
-                logger.info(red('broken    ') + result.uri + red(' - ' + result.message))
-            self.write_entry('broken', result.docname, filename, result.lineno,
-                             result.uri + ': ' + result.message)
-            self.broken_hyperlinks += 1
-        elif result.status == 'redirected':
-            try:
-                text, color = {
-                    301: ('permanently', purple),
-                    302: ('with Found', purple),
-                    303: ('with See Other', purple),
-                    307: ('temporarily', turquoise),
-                    308: ('permanently', purple),
-                }[result.code]
-            except KeyError:
-                text, color = ('with unknown code', purple)
-            linkstat['text'] = text
-            if self.config.linkcheck_allowed_redirects:
-                logger.warning('redirect  ' + result.uri + ' - ' + text + ' to ' +
-                               result.message, location=(result.docname, result.lineno))
-            else:
-                logger.info(color('redirect  ') + result.uri +
-                            color(' - ' + text + ' to ' + result.message))
-            self.write_entry('redirected ' + text, result.docname, filename,
-                             result.lineno, result.uri + ' to ' + result.message)
-        else:
-            raise ValueError('Unknown status %s.' % result.status)
 
-    def write_linkstat(self, data: dict) -> None:
+        match result.status:
+            case _Status.RATE_LIMITED | _Status.UNCHECKED:
+                pass
+            case _Status.IGNORED:
+                if result.message:
+                    msg = f'{res_uri}: {result.message}'
+                else:
+                    msg = res_uri
+                logger.info(darkgray('-ignored- ') + msg)  # NoQA: G003
+            case _Status.WORKING:
+                logger.info(darkgreen('ok        ') + f'{res_uri}{result.message}')  # NoQA: G003
+            case _Status.TIMEOUT:
+                if self.app.quiet:
+                    msg = 'timeout   ' + f'{res_uri}{result.message}'
+                    logger.warning(msg, location=(result.docname, result.lineno))
+                else:
+                    msg = red('timeout   ') + res_uri + red(f' - {result.message}')
+                    logger.info(msg)
+                self.write_entry(
+                    _Status.TIMEOUT,
+                    result.docname,
+                    filename,
+                    result.lineno,
+                    f'{res_uri}: {result.message}',
+                )
+                self.timed_out_hyperlinks += 1
+            case _Status.BROKEN:
+                if self.app.quiet:
+                    logger.warning(
+                        __('broken link: %s (%s)'),
+                        res_uri,
+                        result.message,
+                        location=(result.docname, result.lineno),
+                    )
+                else:
+                    msg = red('broken    ') + res_uri + red(f' - {result.message}')
+                    logger.info(msg)
+                self.write_entry(
+                    _Status.BROKEN,
+                    result.docname,
+                    filename,
+                    result.lineno,
+                    f'{res_uri}: {result.message}',
+                )
+                self.broken_hyperlinks += 1
+            case _Status.REDIRECTED:
+                match result.code:
+                    case 301:
+                        text = 'permanently'
+                    case 302:
+                        text = 'with Found'
+                    case 303:
+                        text = 'with See Other'
+                    case 307:
+                        text = 'temporarily'
+                    case 308:
+                        text = 'permanently'
+                    case _:
+                        text = 'with unknown code'
+                linkstat['text'] = text
+                redirection = f'{text} to {result.message}'
+                if self.config.linkcheck_allowed_redirects:
+                    msg = f'redirect  {res_uri} - {redirection}'
+                    logger.warning(msg, location=(result.docname, result.lineno))
+                else:
+                    colour = turquoise if result.code == 307 else purple
+                    msg = colour('redirect  ') + res_uri + colour(f' - {redirection}')
+                    logger.info(msg)
+                self.write_entry(
+                    f'redirected {text}',
+                    result.docname,
+                    filename,
+                    result.lineno,
+                    f'{res_uri} to {result.message}',
+                )
+            case _Status.UNKNOWN:
+                msg = 'Unknown status.'
+                raise ValueError(msg)
+
+    def write_linkstat(self, data: dict[str, str | int | _Status]) -> None:
         self.json_outfile.write(json.dumps(data))
         self.json_outfile.write('\n')
 
-    def write_entry(self, what: str, docname: str, filename: str, line: int,
-                    uri: str) -> None:
+    def write_entry(
+        self, what: _Status | str, docname: str, filename: _StrPath, line: int, uri: str
+    ) -> None:
         self.txt_outfile.write(f'{filename}:{line}: [{what}] {uri}\n')
 
 
@@ -178,47 +211,75 @@ class HyperlinkCollector(SphinxPostTransform):
     default_priority = 800
 
     def run(self, **kwargs: Any) -> None:
-        builder = cast(CheckExternalLinksBuilder, self.app.builder)
+        for node in self.document.findall():
+            if uri := self.find_uri(node):
+                self._add_uri(uri, node)
+
+    def find_uri(self, node: nodes.Element) -> str | None:
+        """Find a URI for a given node.
+
+        This call can be used to retrieve a URI from a provided node. If no
+        URI exists for a provided node, this call will return ``None``.
+
+        This method can be useful for extension developers who wish to
+        easily inject hyperlinks into a builder by only needing to override
+        this method.
+
+        :param node: A node class
+        :returns: URI of the node
+        """
+        # reference nodes
+        if isinstance(node, nodes.reference):
+            if 'refuri' in node:
+                return node['refuri']
+
+        # image nodes
+        if isinstance(node, nodes.image):
+            uri = node['candidates'].get('?')
+            if uri and '://' in uri:
+                return uri
+
+        # raw nodes
+        if isinstance(node, nodes.raw):
+            uri = node.get('source')
+            if uri and '://' in uri:
+                return uri
+
+        return None
+
+    def _add_uri(self, uri: str, node: nodes.Element) -> None:
+        """Registers a node's URI into a builder's collection of hyperlinks.
+
+        Provides the ability to register a URI value determined from a node
+        into the linkcheck's builder. URI's processed through this call can
+        be manipulated through a ``linkcheck-process-uri`` event before the
+        builder attempts to validate.
+
+        :param uri: URI to add
+        :param node: A node class where the URI was found
+        """
+        builder = cast('CheckExternalLinksBuilder', self.app.builder)
         hyperlinks = builder.hyperlinks
         docname = self.env.docname
 
-        # reference nodes
-        for refnode in self.document.findall(nodes.reference):
-            if 'refuri' in refnode:
-                uri = refnode['refuri']
-                _add_uri(self.app, uri, refnode, hyperlinks, docname)
+        if newuri := self.app.events.emit_firstresult('linkcheck-process-uri', uri):
+            uri = newuri
 
-        # image nodes
-        for imgnode in self.document.findall(nodes.image):
-            uri = imgnode['candidates'].get('?')
-            if uri and '://' in uri:
-                _add_uri(self.app, uri, imgnode, hyperlinks, docname)
+        try:
+            lineno = get_node_line(node)
+        except ValueError:
+            lineno = -1
 
-        # raw nodes
-        for rawnode in self.document.findall(nodes.raw):
-            uri = rawnode.get('source')
-            if uri and '://' in uri:
-                _add_uri(self.app, uri, rawnode, hyperlinks, docname)
-
-
-def _add_uri(app: Sphinx, uri: str, node: nodes.Element,
-             hyperlinks: dict[str, Hyperlink], docname: str) -> None:
-    if newuri := app.emit_firstresult('linkcheck-process-uri', uri):
-        uri = newuri
-
-    try:
-        lineno = get_node_line(node)
-    except ValueError:
-        lineno = -1
-
-    if uri not in hyperlinks:
-        hyperlinks[uri] = Hyperlink(uri, docname, app.env.doc2path(docname), lineno)
+        if uri not in hyperlinks:
+            hyperlinks[uri] = Hyperlink(
+                uri, docname, self.env.doc2path(docname), lineno
+            )
 
 
 class Hyperlink(NamedTuple):
     uri: str
     docname: str
-    docpath: str
+    docpath: _StrPath
     lineno: int
 
 
@@ -231,8 +292,9 @@ class HyperlinkAvailabilityChecker:
         self.wqueue: PriorityQueue[CheckRequest] = PriorityQueue()
         self.num_workers: int = config.linkcheck_workers
 
-        self.to_ignore: list[re.Pattern[str]] = list(map(re.compile,
-                                                         self.config.linkcheck_ignore))
+        self.to_ignore: list[re.Pattern[str]] = list(
+            map(re.compile, self.config.linkcheck_ignore)
+        )
 
     def check(self, hyperlinks: dict[str, Hyperlink]) -> Iterator[CheckResult]:
         self.invoke_threads()
@@ -240,8 +302,14 @@ class HyperlinkAvailabilityChecker:
         total_links = 0
         for hyperlink in hyperlinks.values():
             if self.is_ignored_uri(hyperlink.uri):
-                yield CheckResult(hyperlink.uri, hyperlink.docname, hyperlink.lineno,
-                                  'ignored', '', 0)
+                yield CheckResult(
+                    uri=hyperlink.uri,
+                    docname=hyperlink.docname,
+                    lineno=hyperlink.lineno,
+                    status=_Status.IGNORED,
+                    message='',
+                    code=0,
+                )
             else:
                 self.wqueue.put(CheckRequest(CHECK_IMMEDIATELY, hyperlink), False)
                 total_links += 1
@@ -255,9 +323,9 @@ class HyperlinkAvailabilityChecker:
 
     def invoke_threads(self) -> None:
         for _i in range(self.num_workers):
-            thread = HyperlinkAvailabilityCheckWorker(self.config,
-                                                      self.rqueue, self.wqueue,
-                                                      self.rate_limits)
+            thread = HyperlinkAvailabilityCheckWorker(
+                self.config, self.rqueue, self.wqueue, self.rate_limits
+            )
             thread.start()
             self.workers.append(thread)
 
@@ -279,7 +347,7 @@ class CheckResult(NamedTuple):
     uri: str
     docname: str
     lineno: int
-    status: str
+    status: _Status
     message: str
     code: int
 
@@ -287,41 +355,54 @@ class CheckResult(NamedTuple):
 class HyperlinkAvailabilityCheckWorker(Thread):
     """A worker class for checking the availability of hyperlinks."""
 
-    def __init__(self, config: Config,
-                 rqueue: Queue[CheckResult],
-                 wqueue: Queue[CheckRequest],
-                 rate_limits: dict[str, RateLimit]) -> None:
+    def __init__(
+        self,
+        config: Config,
+        rqueue: Queue[CheckResult],
+        wqueue: Queue[CheckRequest],
+        rate_limits: dict[str, RateLimit],
+    ) -> None:
         self.rate_limits = rate_limits
         self.rqueue = rqueue
         self.wqueue = wqueue
 
         self.anchors_ignore: list[re.Pattern[str]] = list(
-            map(re.compile, config.linkcheck_anchors_ignore))
+            map(re.compile, config.linkcheck_anchors_ignore)
+        )
         self.anchors_ignore_for_url: list[re.Pattern[str]] = list(
-            map(re.compile, config.linkcheck_anchors_ignore_for_url))
+            map(re.compile, config.linkcheck_anchors_ignore_for_url)
+        )
         self.documents_exclude: list[re.Pattern[str]] = list(
-            map(re.compile, config.linkcheck_exclude_documents))
-        self.auth = [(re.compile(pattern), auth_info) for pattern, auth_info
-                     in config.linkcheck_auth]
+            map(re.compile, config.linkcheck_exclude_documents)
+        )
+        self.auth = [
+            (re.compile(pattern), auth_info)
+            for pattern, auth_info in config.linkcheck_auth
+        ]
 
         self.timeout: int | float | None = config.linkcheck_timeout
-        self.request_headers: dict[str, dict[str, str]] = config.linkcheck_request_headers
+        self.request_headers: dict[str, dict[str, str]] = (
+            config.linkcheck_request_headers
+        )
         self.check_anchors: bool = config.linkcheck_anchors
         self.allowed_redirects: dict[re.Pattern[str], re.Pattern[str]]
         self.allowed_redirects = config.linkcheck_allowed_redirects
         self.retries: int = config.linkcheck_retries
         self.rate_limit_timeout = config.linkcheck_rate_limit_timeout
         self._allow_unauthorized = config.linkcheck_allow_unauthorized
+        self._timeout_status: Literal[_Status.BROKEN, _Status.TIMEOUT]
         if config.linkcheck_report_timeouts_as_broken:
-            self._timeout_status = 'broken'
+            self._timeout_status = _Status.BROKEN
         else:
-            self._timeout_status = 'timeout'
+            self._timeout_status = _Status.TIMEOUT
 
         self.user_agent = config.user_agent
         self.tls_verify = config.tls_verify
         self.tls_cacerts = config.tls_cacerts
 
-        self._session = requests._Session()
+        self._session = requests._Session(
+            _ignored_redirects=tuple(map(re.compile, config.linkcheck_ignore))
+        )
 
         super().__init__(daemon=True)
 
@@ -352,13 +433,15 @@ class HyperlinkAvailabilityCheckWorker(Thread):
                 self.wqueue.task_done()
                 continue
             status, info, code = self._check(docname, uri, hyperlink)
-            if status == 'rate-limited':
-                logger.info(darkgray('-rate limited-   ') + uri + darkgray(' | sleeping...'))
+            if status == _Status.RATE_LIMITED:
+                logger.info(
+                    darkgray('-rate limited-   ') + uri + darkgray(' | sleeping...')  # NoQA: G003
+                )
             else:
                 self.rqueue.put(CheckResult(uri, docname, lineno, status, info, code))
             self.wqueue.task_done()
 
-    def _check(self, docname: str, uri: str, hyperlink: Hyperlink) -> tuple[str, str, int]:
+    def _check(self, docname: str, uri: str, hyperlink: Hyperlink) -> _URIProperties:
         # check for various conditions without bothering the network
 
         for doc_matcher in self.documents_exclude:
@@ -367,37 +450,39 @@ class HyperlinkAvailabilityCheckWorker(Thread):
                     f'{docname} matched {doc_matcher.pattern} from '
                     'linkcheck_exclude_documents'
                 )
-                return 'ignored', info, 0
+                return _Status.IGNORED, info, 0
 
         if len(uri) == 0 or uri.startswith(('#', 'mailto:', 'tel:')):
-            return 'unchecked', '', 0
+            return _Status.UNCHECKED, '', 0
         if not uri.startswith(('http:', 'https:')):
             if uri_re.match(uri):
                 # Non-supported URI schemes (ex. ftp)
-                return 'unchecked', '', 0
+                return _Status.UNCHECKED, '', 0
 
-            src_dir = path.dirname(hyperlink.docpath)
-            if path.exists(path.join(src_dir, uri)):
-                return 'working', '', 0
-            return 'broken', '', 0
+            if (hyperlink.docpath.parent / uri).exists():
+                return _Status.WORKING, '', 0
+            return _Status.BROKEN, '', 0
 
         # need to actually check the URI
-        status, info, code = '', '', 0
+        status: _Status
+        status, info, code = _Status.UNKNOWN, '', 0
         for _ in range(self.retries):
             status, info, code = self._check_uri(uri, hyperlink)
-            if status != 'broken':
+            if status != _Status.BROKEN:
                 break
 
         return status, info, code
 
-    def _retrieval_methods(self,
-                           check_anchors: bool,
-                           anchor: str) -> Iterator[tuple[Callable, dict]]:
+    def _retrieval_methods(
+        self,
+        check_anchors: bool,
+        anchor: str,
+    ) -> Iterator[tuple[Callable[..., Response], dict[str, bool]]]:
         if not check_anchors or not anchor:
             yield self._session.head, {'allow_redirects': True}
         yield self._session.get, {'stream': True}
 
-    def _check_uri(self, uri: str, hyperlink: Hyperlink) -> tuple[str, str, int]:
+    def _check_uri(self, uri: str, hyperlink: Hyperlink) -> _URIProperties:
         req_url, delimiter, anchor = uri.partition('#')
         if delimiter and anchor:
             for rex in self.anchors_ignore:
@@ -409,6 +494,7 @@ class HyperlinkAvailabilityCheckWorker(Thread):
                     if rex.match(req_url):
                         anchor = ''
                         break
+            anchor = unquote(anchor)
 
         # handle non-ASCII URIs
         try:
@@ -434,24 +520,41 @@ class HyperlinkAvailabilityCheckWorker(Thread):
         error_message = ''
         status_code = -1
         response_url = retry_after = ''
-        for retrieval_method, kwargs in self._retrieval_methods(self.check_anchors, anchor):
+        for retrieval_method, kwargs in self._retrieval_methods(
+            self.check_anchors, anchor
+        ):
             try:
                 with retrieval_method(
-                    url=req_url, auth=auth_info,
+                    url=req_url,
+                    auth=auth_info,
                     headers=headers,
                     timeout=self.timeout,
                     **kwargs,
                     _user_agent=self.user_agent,
                     _tls_info=(self.tls_verify, self.tls_cacerts),
                 ) as response:
-                    if (self.check_anchors and response.ok and anchor
-                            and not contains_anchor(response, anchor)):
-                        raise Exception(__(f'Anchor {anchor!r} not found'))
+                    if anchor and self.check_anchors and response.ok:
+                        try:
+                            found = contains_anchor(response, anchor)
+                        except UnicodeDecodeError:
+                            return (
+                                _Status.IGNORED,
+                                'unable to decode response content',
+                                0,
+                            )
+                        if not found:
+                            return (
+                                _Status.BROKEN,
+                                __("Anchor '%s' not found") % quote(anchor),
+                                0,
+                            )
 
                 # Copy data we need from the (closed) response
                 status_code = response.status_code
-                redirect_status_code = response.history[-1].status_code if response.history else None  # NoQA: E501
-                retry_after = response.headers.get('Retry-After')
+                redirect_status_code = (
+                    response.history[-1].status_code if response.history else None
+                )
+                retry_after = response.headers.get('Retry-After', '')
                 response_url = f'{response.url}'
                 response.raise_for_status()
                 del response
@@ -462,7 +565,7 @@ class HyperlinkAvailabilityCheckWorker(Thread):
 
             except SSLError as err:
                 # SSL failure; report that the link is broken.
-                return 'broken', str(err), 0
+                return _Status.BROKEN, str(err), 0
 
             except (ConnectionError, TooManyRedirects) as err:
                 # Servers drop the connection on HEAD requests, causing
@@ -470,45 +573,34 @@ class HyperlinkAvailabilityCheckWorker(Thread):
                 error_message = str(err)
                 continue
 
+            except requests._IgnoredRedirection as err:
+                # A redirection to an ignored URI was attempted; report it appropriately
+                return (
+                    _Status.IGNORED,
+                    f'ignored redirect: {err.destination}',
+                    err.status_code,
+                )
+
             except HTTPError as err:
                 error_message = str(err)
 
                 # Unauthorized: the client did not provide required credentials
                 if status_code == 401:
                     if self._allow_unauthorized:
-                        deprecation_msg = (
-                            "\n---\n"
-                            "The linkcheck builder encountered an HTTP 401 "
-                            "(unauthorized) response, and will report it as "
-                            "'working' in this version of Sphinx to maintain "
-                            "backwards-compatibility."
-                            "\n"
-                            "This logic will change in Sphinx 8.0 which will "
-                            "report the hyperlink as 'broken'."
-                            "\n"
-                            "To explicitly continue treating unauthorized "
-                            "hyperlink responses as 'working', set the "
-                            "'linkcheck_allow_unauthorized' config option to "
-                            "``True``."
-                            "\n"
-                            "See https://github.com/sphinx-doc/sphinx/issues/11433 "
-                            "for details."
-                            "\n---"
-                        )
-                        warnings.warn(deprecation_msg, RemovedInSphinx80Warning, stacklevel=1)
-                    status = 'working' if self._allow_unauthorized else 'broken'
-                    return status, 'unauthorized', 0
+                        return _Status.WORKING, 'unauthorized', 0
+                    else:
+                        return _Status.BROKEN, 'unauthorized', 0
 
                 # Rate limiting; back-off if allowed, or report failure otherwise
                 if status_code == 429:
                     if next_check := self.limit_rate(response_url, retry_after):
                         self.wqueue.put(CheckRequest(next_check, hyperlink), False)
-                        return 'rate-limited', '', 0
-                    return 'broken', error_message, 0
+                        return _Status.RATE_LIMITED, '', 0
+                    return _Status.BROKEN, error_message, 0
 
                 # Don't claim success/failure during server-side outages
                 if status_code == 503:
-                    return 'ignored', 'service unavailable', 0
+                    return _Status.IGNORED, 'service unavailable', 0
 
                 # For most HTTP failures, continue attempting alternate retrieval methods
                 continue
@@ -516,27 +608,28 @@ class HyperlinkAvailabilityCheckWorker(Thread):
             except Exception as err:
                 # Unhandled exception (intermittent or permanent); report that
                 # the link is broken.
-                return 'broken', str(err), 0
+                return _Status.BROKEN, str(err), 0
 
         else:
             # All available retrieval methods have been exhausted; report
             # that the link is broken.
-            return 'broken', error_message, 0
+            return _Status.BROKEN, error_message, 0
 
         # Success; clear rate limits for the origin
         netloc = urlsplit(req_url).netloc
         self.rate_limits.pop(netloc, None)
 
-        if ((response_url.rstrip('/') == req_url.rstrip('/'))
-                or _allowed_redirect(req_url, response_url,
-                                     self.allowed_redirects)):
-            return 'working', '', 0
+        if (
+            (response_url.rstrip('/') == req_url.rstrip('/'))
+            or _allowed_redirect(req_url, response_url, self.allowed_redirects)
+        ):  # fmt: skip
+            return _Status.WORKING, '', 0
         elif redirect_status_code is not None:
-            return 'redirected', response_url, redirect_status_code
+            return _Status.REDIRECTED, response_url, redirect_status_code
         else:
-            return 'redirected', response_url, 0
+            return _Status.REDIRECTED, response_url, 0
 
-    def limit_rate(self, response_url: str, retry_after: str) -> float | None:
+    def limit_rate(self, response_url: str, retry_after: str | None) -> float | None:
         delay = DEFAULT_DELAY
         next_check = None
         if retry_after:
@@ -579,10 +672,12 @@ def _get_request_headers(
     request_headers: dict[str, dict[str, str]],
 ) -> dict[str, str]:
     url = urlsplit(uri)
-    candidates = (f'{url.scheme}://{url.netloc}',
-                  f'{url.scheme}://{url.netloc}/',
-                  uri,
-                  '*')
+    candidates = (
+        f'{url.scheme}://{url.netloc}',
+        f'{url.scheme}://{url.netloc}/',
+        uri,
+        '*',
+    )
 
     for u in candidates:
         if u in request_headers:
@@ -592,12 +687,13 @@ def _get_request_headers(
 
 def contains_anchor(response: Response, anchor: str) -> bool:
     """Determine if an anchor is contained within an HTTP response."""
-    parser = AnchorCheckParser(unquote(anchor))
+    parser = AnchorCheckParser(anchor)
     # Read file in chunks. If we find a matching anchor, we break
     # the loop early in hopes not to have to download the whole thing.
     for chunk in response.iter_content(chunk_size=4096, decode_unicode=True):
-        if isinstance(chunk, bytes):    # requests failed to decode
-            chunk = chunk.decode()      # manually try to decode it
+        if isinstance(chunk, bytes):
+            # requests failed to decode, manually try to decode it
+            chunk = chunk.decode()
 
         parser.feed(chunk)
         if parser.found:
@@ -617,17 +713,17 @@ class AnchorCheckParser(HTMLParser):
 
     def handle_starttag(self, tag: Any, attrs: Any) -> None:
         for key, value in attrs:
-            if key in ('id', 'name') and value == self.search_anchor:
+            if key in {'id', 'name'} and value == self.search_anchor:
                 self.found = True
                 break
 
 
-def _allowed_redirect(url: str, new_url: str,
-                      allowed_redirects: dict[re.Pattern[str], re.Pattern[str]]) -> bool:
+def _allowed_redirect(
+    url: str, new_url: str, allowed_redirects: dict[re.Pattern[str], re.Pattern[str]]
+) -> bool:
     return any(
         from_url.match(url) and to_url.match(new_url)
-        for from_url, to_url
-        in allowed_redirects.items()
+        for from_url, to_url in allowed_redirects.items()
     )
 
 
@@ -653,44 +749,60 @@ def rewrite_github_anchor(app: Sphinx, uri: str) -> str | None:
 
 def compile_linkcheck_allowed_redirects(app: Sphinx, config: Config) -> None:
     """Compile patterns in linkcheck_allowed_redirects to the regexp objects."""
-    for url, pattern in list(app.config.linkcheck_allowed_redirects.items()):
+    linkcheck_allowed_redirects = app.config.linkcheck_allowed_redirects
+    for url, pattern in list(linkcheck_allowed_redirects.items()):
         try:
-            app.config.linkcheck_allowed_redirects[re.compile(url)] = re.compile(pattern)
+            linkcheck_allowed_redirects[re.compile(url)] = re.compile(pattern)
         except re.error as exc:
-            logger.warning(__('Failed to compile regex in linkcheck_allowed_redirects: %r %s'),
-                           exc.pattern, exc.msg)
+            logger.warning(
+                __('Failed to compile regex in linkcheck_allowed_redirects: %r %s'),
+                exc.pattern,
+                exc.msg,
+            )
         finally:
             # Remove the original regexp-string
-            app.config.linkcheck_allowed_redirects.pop(url)
+            linkcheck_allowed_redirects.pop(url)
 
 
 def setup(app: Sphinx) -> ExtensionMetadata:
     app.add_builder(CheckExternalLinksBuilder)
     app.add_post_transform(HyperlinkCollector)
 
-    app.add_config_value('linkcheck_ignore', [], '')
-    app.add_config_value('linkcheck_exclude_documents', [], '')
-    app.add_config_value('linkcheck_allowed_redirects', {}, '')
-    app.add_config_value('linkcheck_auth', [], '')
-    app.add_config_value('linkcheck_request_headers', {}, '')
-    app.add_config_value('linkcheck_retries', 1, '')
-    app.add_config_value('linkcheck_timeout', 30, '', (int, float))
-    app.add_config_value('linkcheck_workers', 5, '')
-    app.add_config_value('linkcheck_anchors', True, '')
+    app.add_config_value('linkcheck_ignore', [], '', types=frozenset({list, tuple}))
+    app.add_config_value(
+        'linkcheck_exclude_documents', [], '', types=frozenset({list, tuple})
+    )
+    app.add_config_value('linkcheck_allowed_redirects', {}, '', types=frozenset({dict}))
+    app.add_config_value('linkcheck_auth', [], '', types=frozenset({list, tuple}))
+    app.add_config_value('linkcheck_request_headers', {}, '', types=frozenset({dict}))
+    app.add_config_value('linkcheck_retries', 1, '', types=frozenset({int}))
+    app.add_config_value('linkcheck_timeout', 30, '', types=frozenset({float, int}))
+    app.add_config_value('linkcheck_workers', 5, '', types=frozenset({int}))
+    app.add_config_value('linkcheck_anchors', True, '', types=frozenset({bool}))
     # Anchors starting with ! are ignored since they are
     # commonly used for dynamic pages
-    app.add_config_value('linkcheck_anchors_ignore', ['^!'], '')
-    app.add_config_value('linkcheck_anchors_ignore_for_url', (), '', (tuple, list))
-    app.add_config_value('linkcheck_rate_limit_timeout', 300.0, '')
-    app.add_config_value('linkcheck_allow_unauthorized', True, '')
-    app.add_config_value('linkcheck_report_timeouts_as_broken', True, '', bool)
+    app.add_config_value(
+        'linkcheck_anchors_ignore', ['^!'], '', types=frozenset({list, tuple})
+    )
+    app.add_config_value(
+        'linkcheck_anchors_ignore_for_url', (), '', types=frozenset({list, tuple})
+    )
+    app.add_config_value(
+        'linkcheck_rate_limit_timeout', 300.0, '', types=frozenset({float, int})
+    )
+    app.add_config_value(
+        'linkcheck_allow_unauthorized', False, '', types=frozenset({bool})
+    )
+    app.add_config_value(
+        'linkcheck_report_timeouts_as_broken', False, '', types=frozenset({bool})
+    )
 
     app.add_event('linkcheck-process-uri')
 
     app.connect('config-inited', compile_linkcheck_allowed_redirects, priority=800)
 
     # FIXME: Disable URL rewrite handler for github.com temporarily.
-    # ref: https://github.com/sphinx-doc/sphinx/issues/9435
+    # See: https://github.com/sphinx-doc/sphinx/issues/9435
     # app.connect('linkcheck-process-uri', rewrite_github_anchor)
 
     return {
