@@ -2,8 +2,6 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Dict, Set
-
 import snowballstemmer
 
 from sphinx.search import SearchLanguage
@@ -15,7 +13,7 @@ class SearchRomanian(SearchLanguage):
     js_stemmer_rawcode = 'romanian-stemmer.js'
     stopwords: set[str] = set()
 
-    def init(self, options: dict) -> None:
+    def init(self, options: dict[str, str]) -> None:
         self.stemmer = snowballstemmer.stemmer('romanian')
 
     def stem(self, word: str) -> str:
