@@ -18,9 +18,15 @@ from sphinx.testing.util import _clean_up_global_state
 if TYPE_CHECKING:
     from collections.abc import Iterator
 
+_TESTS_ROOT = Path(__file__).resolve().parent
+if 'CI' in os.environ and (_TESTS_ROOT / 'roots-read-only').is_dir():
+    _ROOTS_DIR = _TESTS_ROOT / 'roots-read-only'
+else:
+    _ROOTS_DIR = _TESTS_ROOT / 'roots'
+
 
 def _init_console(
-    locale_dir: str | None = sphinx.locale._LOCALE_DIR,
+    locale_dir: str | os.PathLike[str] | None = sphinx.locale._LOCALE_DIR,
     catalog: str = 'sphinx',
 ) -> tuple[gettext.NullTranslations, bool]:
     """Monkeypatch ``init_console`` to skip its action.
@@ -44,16 +50,19 @@ os.environ['SPHINX_AUTODOC_RELOAD_MODULES'] = '1'
 
 @pytest.fixture(scope='session')
 def rootdir() -> Path:
-    return Path(__file__).parent.resolve() / 'roots'
+    return _ROOTS_DIR
 
 
 def pytest_report_header(config: pytest.Config) -> str:
-    header = f'libraries: Sphinx-{sphinx.__display_version__}, docutils-{docutils.__version__}'
+    lines = [
+        f'libraries: Sphinx-{sphinx.__display_version__}, docutils-{docutils.__version__}',
+    ]
     if sys.version_info[:2] >= (3, 13):
-        header += f'\nGIL enabled?: {sys._is_gil_enabled()}'
+        lines.append(f'GIL enabled?: {sys._is_gil_enabled()}')
+    lines.append(f'test roots directory: {_ROOTS_DIR}')
     if hasattr(config, '_tmp_path_factory'):
-        header += f'\nbase tmp_path: {config._tmp_path_factory.getbasetemp()}'
-    return header
+        lines.append(f'base tmp_path: {config._tmp_path_factory.getbasetemp()}')
+    return '\n'.join(lines)
 
 
 @pytest.fixture(autouse=True)
@@ -80,3 +89,14 @@ def _http_teapot(monkeypatch: pytest.MonkeyPatch) -> Iterator[None]:
     with monkeypatch.context() as m:
         m.setattr('sphinx.util.requests._Session.request', _request)
         yield
+
+
+@pytest.fixture
+def make_app_with_empty_project(make_app, tmp_path):
+    (tmp_path / 'conf.py').touch()
+
+    def _make_app(*args, **kw):
+        kw.setdefault('srcdir', Path(tmp_path))
+        return make_app(*args, **kw)
+
+    return _make_app
