@@ -1,7 +1,8 @@
 class Example:
     """Example class"""
-    num_attribute = 5
-    text_attribute = "string"
 
-    relevance = "testing"
+    num_attribute = 5
+    text_attribute = 'string'
+
+    relevance = 'testing'
     """attribute docstring"""
