@@ -7,9 +7,11 @@ class Foo:
 class Bar:
     """docstring"""
 
-    __slots__ = {'attr1': 'docstring of attr1',
-                 'attr2': 'docstring of attr2',
-                 'attr3': None}
+    __slots__ = {
+        'attr1': 'docstring of attr1',
+        'attr2': 'docstring of attr2',
+        'attr3': None,
+    }
     __annotations__ = {'attr1': int}
 
     def __init__(self):
@@ -19,4 +21,4 @@ class Bar:
 class Baz:
     """docstring"""
 
-    __slots__ = 'attr'
+    __slots__ = 'attr'  # NoQA: PLC0205
