@@ -3,6 +3,6 @@ extensions = ['sphinx.ext.doctest']
 project = 'test project for doctest'
 root_doc = 'doctest'
 source_suffix = {
-    '.txt': 'restructuredtext'
+    '.txt': 'restructuredtext',
 }
 exclude_patterns = ['_build']
