@@ -1,6 +1,4 @@
-"""
-mod2
-"""
+"""mod2"""
 
 
 def decorator(f):
@@ -9,14 +7,10 @@ def decorator(f):
 
 @decorator
 def func2(a, b):
-    """
-    this is func2
-    """
+    """this is func2"""
     return a, b
 
 
 @decorator
 class Class2:
-    """
-    this is Class2
-    """
+    """this is Class2"""
