@@ -1,5 +1,5 @@
 project = 'versioning test root'
 source_suffix = {
-    '.txt': 'restructuredtext'
+    '.txt': 'restructuredtext',
 }
 exclude_patterns = ['_build']
