@@ -12,7 +12,7 @@ if TYPE_CHECKING:
     from collections.abc import Iterator
 
 
-@pytest.fixture()
+@pytest.fixture
 def sig_elements() -> Iterator[set[type[addnodes.desc_sig_element]]]:
     """Fixture returning the current ``addnodes.SIG_ELEMENTS`` set."""
     original = addnodes.SIG_ELEMENTS.copy()  # safe copy of the current nodes
