@@ -13,10 +13,10 @@ import pytest
 from docutils import nodes
 
 import sphinx.application
+from sphinx._cli.util.errors import strip_escape_sequences
 from sphinx.errors import ExtensionError
 from sphinx.testing.util import SphinxTestApp
 from sphinx.util import logging
-from sphinx.util.console import strip_colors
 
 if TYPE_CHECKING:
     import os
@@ -49,7 +49,7 @@ def test_instantiation(
 
 
 @pytest.mark.sphinx('html', testroot='root')
-def test_events(app):
+def test_events(app: SphinxTestApp) -> None:
     def empty():
         pass
 
@@ -76,27 +76,27 @@ def test_events(app):
 
 
 @pytest.mark.sphinx('html', testroot='root')
-def test_emit_with_nonascii_name_node(app):
+def test_emit_with_nonascii_name_node(app: SphinxTestApp) -> None:
     node = nodes.section(names=['\u65e5\u672c\u8a9e'])
     app.emit('my_event', node)
 
 
 @pytest.mark.sphinx('html', testroot='root')
-def test_extensions(app):
+def test_extensions(app: SphinxTestApp) -> None:
     app.setup_extension('shutil')
-    warning = strip_colors(app.warning.getvalue())
+    warning = strip_escape_sequences(app.warning.getvalue())
     assert "extension 'shutil' has no setup() function" in warning
 
 
 @pytest.mark.sphinx('html', testroot='root')
-def test_extension_in_blacklist(app):
+def test_extension_in_blacklist(app: SphinxTestApp) -> None:
     app.setup_extension('sphinxjp.themecore')
-    msg = strip_colors(app.warning.getvalue())
+    msg = strip_escape_sequences(app.warning.getvalue())
     assert msg.startswith("WARNING: the extension 'sphinxjp.themecore' was")
 
 
 @pytest.mark.sphinx('html', testroot='add_source_parser')
-def test_add_source_parser(app):
+def test_add_source_parser(app: SphinxTestApp) -> None:
     assert set(app.config.source_suffix) == {'.rst', '.test'}
 
     # .rst; only in :confval:`source_suffix`
@@ -110,7 +110,7 @@ def test_add_source_parser(app):
 
 
 @pytest.mark.sphinx('html', testroot='extensions')
-def test_add_is_parallel_allowed(app):
+def test_add_is_parallel_allowed(app: SphinxTestApp) -> None:
     logging.setup(app, app.status, app.warning)
 
     assert app.is_parallel_allowed('read') is True
@@ -155,14 +155,14 @@ def test_add_is_parallel_allowed(app):
 
 
 @pytest.mark.sphinx('dummy', testroot='root')
-def test_build_specific(app):
-    app.builder.build = Mock()
+def test_build_specific(app: SphinxTestApp) -> None:
+    app.builder.build = Mock()  # type: ignore[method-assign,misc]
     filenames = [
         app.srcdir / 'index.txt',                      # normal
         app.srcdir / 'images',                         # without suffix
         app.srcdir / 'notfound.txt',                   # not found
         app.srcdir / 'img.png',                        # unknown suffix
-        '/index.txt',                                  # external file
+        Path('/index.txt'),                            # external file
         app.srcdir / 'subdir',                         # directory
         app.srcdir / 'subdir/includes.txt',            # file on subdir
         app.srcdir / 'subdir/../subdir/excluded.txt',  # not normalized
