@@ -1,12 +1,20 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
+import pygments
 import pytest
 
+if TYPE_CHECKING:
+    from sphinx.testing.util import SphinxTestApp
+
 
 @pytest.mark.sphinx(
     'html',
     testroot='reST-code-block',
     confoverrides={'html_codeblock_linenos_style': 'table'},
 )
-def test_html_codeblock_linenos_style_table(app):
+def test_html_codeblock_linenos_style_table(app: SphinxTestApp) -> None:
     app.build()
     content = (app.outdir / 'index.html').read_text(encoding='utf8')
 
@@ -23,7 +31,7 @@ def test_html_codeblock_linenos_style_table(app):
     testroot='reST-code-block',
     confoverrides={'html_codeblock_linenos_style': 'inline'},
 )
-def test_html_codeblock_linenos_style_inline(app):
+def test_html_codeblock_linenos_style_inline(app: SphinxTestApp) -> None:
     app.build()
     content = (app.outdir / 'index.html').read_text(encoding='utf8')
 
@@ -31,12 +39,17 @@ def test_html_codeblock_linenos_style_inline(app):
 
 
 @pytest.mark.sphinx('html', testroot='reST-code-role')
-def test_html_code_role(app):
+def test_html_code_role(app: SphinxTestApp) -> None:
+    if tuple(map(int, pygments.__version__.split('.')[:2])) >= (2, 19):
+        sp = '<span class="w"> </span>'
+    else:
+        sp = ' '
+
     app.build()
     content = (app.outdir / 'index.html').read_text(encoding='utf8')
 
     common_content = (
-        '<span class="k">def</span> <span class="nf">foo</span>'
+        f'<span class="k">def</span>{sp}<span class="nf">foo</span>'
         '<span class="p">(</span>'
         '<span class="mi">1</span> '
         '<span class="o">+</span> '
