@@ -1,17 +1,22 @@
 """Test the HTML builder and check output against XPath."""
 
-import os
+from __future__ import annotations
+
 import re
+from typing import TYPE_CHECKING
 
 import pytest
 
 from tests.test_builders.xpath_data import FIGURE_CAPTION
 from tests.test_builders.xpath_util import check_xpath
 
+if TYPE_CHECKING:
+    from sphinx.testing.util import SphinxTestApp
+
 
 @pytest.mark.sphinx('html', testroot='numfig')
 @pytest.mark.test_params(shared_result='test_build_html_numfig')
-def test_numfig_disabled_warn(app):
+def test_numfig_disabled_warn(app: SphinxTestApp) -> None:
     app.build()
     warnings = app.warning.getvalue()
     assert 'index.rst:47: WARNING: numfig is disabled. :numref: is ignored.' in warnings
@@ -79,7 +84,7 @@ def test_numfig_disabled(app, cached_etree_parse, fname, path, check, be_found):
     srcdir='test_numfig_without_numbered_toctree_warn',
     confoverrides={'numfig': True},
 )
-def test_numfig_without_numbered_toctree_warn(app):
+def test_numfig_without_numbered_toctree_warn(app: SphinxTestApp) -> None:
     app.build()
     # remove :numbered: option
     index = (app.srcdir / 'index.rst').read_text(encoding='utf8')
@@ -307,7 +312,7 @@ def test_numfig_without_numbered_toctree(
     index = re.sub(':numbered:.*', '', index)
     (app.srcdir / 'index.rst').write_text(index, encoding='utf8')
 
-    if not os.listdir(app.outdir):
+    if not list(app.outdir.iterdir()):
         app.build()
     check_xpath(cached_etree_parse(app.outdir / fname), fname, path, check, be_found)
 
@@ -318,7 +323,7 @@ def test_numfig_without_numbered_toctree(
     confoverrides={'numfig': True},
 )
 @pytest.mark.test_params(shared_result='test_build_html_numfig_on')
-def test_numfig_with_numbered_toctree_warn(app):
+def test_numfig_with_numbered_toctree_warn(app: SphinxTestApp) -> None:
     app.build()
     warnings = app.warning.getvalue()
     assert (
@@ -553,7 +558,7 @@ def test_numfig_with_numbered_toctree(
     },
 )
 @pytest.mark.test_params(shared_result='test_build_html_numfig_format_warn')
-def test_numfig_with_prefix_warn(app):
+def test_numfig_with_prefix_warn(app: SphinxTestApp) -> None:
     app.build()
     warnings = app.warning.getvalue()
     assert (
@@ -786,7 +791,7 @@ def test_numfig_with_prefix(app, cached_etree_parse, fname, path, check, be_foun
     confoverrides={'numfig': True, 'numfig_secnum_depth': 2},
 )
 @pytest.mark.test_params(shared_result='test_build_html_numfig_depth_2')
-def test_numfig_with_secnum_depth_warn(app):
+def test_numfig_with_secnum_depth_warn(app: SphinxTestApp) -> None:
     app.build()
     warnings = app.warning.getvalue()
     assert (
