@@ -5,4 +5,4 @@ from typing import TYPE_CHECKING
 if TYPE_CHECKING:
     from typing import Final
 
-FIGURE_CAPTION: Final[str] = ".//figure/figcaption/p"
+FIGURE_CAPTION: Final[str] = './/figure/figcaption/p'
