@@ -1,5 +1,8 @@
 """Tests the std domain"""
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 from unittest import mock
 
 import pytest
@@ -19,12 +22,15 @@ from sphinx.addnodes import (
 )
 from sphinx.domains.std import StandardDomain
 from sphinx.testing import restructuredtext
-from sphinx.testing.util import assert_node, etree_parse
+from sphinx.testing.util import assert_node
+
+if TYPE_CHECKING:
+    from sphinx.testing.util import SphinxTestApp
 
 
-def test_process_doc_handle_figure_caption():
+def test_process_doc_handle_figure_caption() -> None:
     env = mock.Mock(domaindata={})
-    env.app.registry.enumerable_nodes = {}
+    env._registry.enumerable_nodes = {}
     figure_node = nodes.figure(
         '',
         nodes.caption('caption text', 'caption text'),
@@ -45,9 +51,9 @@ def test_process_doc_handle_figure_caption():
     assert domain.data['labels']['testname'] == ('testdoc', 'testid', 'caption text')
 
 
-def test_process_doc_handle_table_title():
+def test_process_doc_handle_table_title() -> None:
     env = mock.Mock(domaindata={})
-    env.app.registry.enumerable_nodes = {}
+    env._registry.enumerable_nodes = {}
     table_node = nodes.table(
         '',
         nodes.title('title text', 'title text'),
@@ -68,9 +74,9 @@ def test_process_doc_handle_table_title():
     assert domain.data['labels']['testname'] == ('testdoc', 'testid', 'title text')
 
 
-def test_get_full_qualified_name():
+def test_get_full_qualified_name() -> None:
     env = mock.Mock(domaindata={})
-    env.app.registry.enumerable_nodes = {}
+    env._registry.enumerable_nodes = {}
     domain = StandardDomain(env)
 
     # normal references
@@ -87,8 +93,8 @@ def test_get_full_qualified_name():
     assert domain.get_full_qualified_name(node) == 'ls.-l'
 
 
-@pytest.mark.sphinx('html', testroot='root')
-def test_cmd_option_with_optional_value(app):
+@pytest.mark.sphinx('html', testroot='_blank')
+def test_cmd_option_with_optional_value(app: SphinxTestApp) -> None:
     text = '.. option:: -j[=N]'
     doctree = restructuredtext.parse(app, text)
     assert_node(
@@ -114,8 +120,8 @@ def test_cmd_option_with_optional_value(app):
     assert ('-j', '-j', 'cmdoption', 'index', 'cmdoption-j', 1) in objects
 
 
-@pytest.mark.sphinx('html', testroot='root')
-def test_cmd_option_starting_with_bracket(app):
+@pytest.mark.sphinx('html', testroot='_blank')
+def test_cmd_option_starting_with_bracket(app: SphinxTestApp) -> None:
     text = '.. option:: [enable=]PATTERN'
     doctree = restructuredtext.parse(app, text)
     assert_node(
@@ -145,7 +151,7 @@ def test_cmd_option_starting_with_bracket(app):
     ) in objects
 
 
-@pytest.mark.sphinx('html', testroot='root')
+@pytest.mark.sphinx('html', testroot='_blank')
 def test_glossary(app):
     text = (
         '.. glossary::\n'
@@ -241,8 +247,8 @@ def test_glossary(app):
     assert_node(refnode, nodes.reference, refid='term-TERM2')
 
 
-@pytest.mark.sphinx('html', testroot='root')
-def test_glossary_warning(app):
+@pytest.mark.sphinx('html', testroot='_blank')
+def test_glossary_warning(app: SphinxTestApp) -> None:
     # empty line between terms
     text = '.. glossary::\n\n   term1\n\n   term2\n'
     restructuredtext.parse(app, text, 'case1')
@@ -273,7 +279,7 @@ def test_glossary_warning(app):
     ) in app.warning.getvalue()
 
 
-@pytest.mark.sphinx('html', testroot='root')
+@pytest.mark.sphinx('html', testroot='_blank')
 def test_glossary_comment(app):
     text = (
         '.. glossary::\n'
@@ -299,7 +305,7 @@ def test_glossary_comment(app):
     assert_node(doctree[0][0][0][1], [nodes.definition, nodes.paragraph, 'description'])
 
 
-@pytest.mark.sphinx('html', testroot='root')
+@pytest.mark.sphinx('html', testroot='_blank')
 def test_glossary_comment2(app):
     text = (
         '.. glossary::\n'
@@ -333,7 +339,7 @@ def test_glossary_comment2(app):
     )
 
 
-@pytest.mark.sphinx('html', testroot='root')
+@pytest.mark.sphinx('html', testroot='_blank')
 def test_glossary_sorted(app):
     text = (
         '.. glossary::\n'
@@ -371,8 +377,8 @@ def test_glossary_sorted(app):
     assert_node(doctree[0][0][1][1], [nodes.definition, nodes.paragraph, 'description'])
 
 
-@pytest.mark.sphinx('html', testroot='root')
-def test_glossary_alphanumeric(app):
+@pytest.mark.sphinx('html', testroot='_blank')
+def test_glossary_alphanumeric(app: SphinxTestApp) -> None:
     text = '.. glossary::\n\n   1\n   /\n'
     restructuredtext.parse(app, text)
     objects = list(app.env.domains.standard_domain.get_objects())
@@ -380,16 +386,16 @@ def test_glossary_alphanumeric(app):
     assert ('/', '/', 'term', 'index', 'term-0', -1) in objects
 
 
-@pytest.mark.sphinx('html', testroot='root')
-def test_glossary_conflicted_labels(app):
+@pytest.mark.sphinx('html', testroot='_blank')
+def test_glossary_conflicted_labels(app: SphinxTestApp) -> None:
     text = '.. _term-foo:\n.. glossary::\n\n   foo\n'
     restructuredtext.parse(app, text)
     objects = list(app.env.domains.standard_domain.get_objects())
     assert ('foo', 'foo', 'term', 'index', 'term-0', -1) in objects
 
 
-@pytest.mark.sphinx('html', testroot='root')
-def test_cmdoption(app):
+@pytest.mark.sphinx('html', testroot='_blank')
+def test_cmdoption(app: SphinxTestApp) -> None:
     text = '.. program:: ls\n\n.. option:: -l\n'
     domain = app.env.domains.standard_domain
     doctree = restructuredtext.parse(app, text)
@@ -412,11 +418,11 @@ def test_cmdoption(app):
         entries=[('pair', 'ls command line option; -l', 'cmdoption-ls-l', '', None)],
     )
     assert ('ls', '-l') in domain.progoptions
-    assert domain.progoptions[('ls', '-l')] == ('index', 'cmdoption-ls-l')
+    assert domain.progoptions['ls', '-l'] == ('index', 'cmdoption-ls-l')
 
 
-@pytest.mark.sphinx('html', testroot='root')
-def test_cmdoption_for_None(app):
+@pytest.mark.sphinx('html', testroot='_blank')
+def test_cmdoption_for_None(app: SphinxTestApp) -> None:
     text = '.. program:: ls\n.. program:: None\n\n.. option:: -l\n'
     domain = app.env.domains.standard_domain
     doctree = restructuredtext.parse(app, text)
@@ -439,11 +445,11 @@ def test_cmdoption_for_None(app):
         entries=[('pair', 'command line option; -l', 'cmdoption-l', '', None)],
     )
     assert (None, '-l') in domain.progoptions
-    assert domain.progoptions[(None, '-l')] == ('index', 'cmdoption-l')
+    assert domain.progoptions[None, '-l'] == ('index', 'cmdoption-l')
 
 
-@pytest.mark.sphinx('html', testroot='root')
-def test_multiple_cmdoptions(app):
+@pytest.mark.sphinx('html', testroot='_blank')
+def test_multiple_cmdoptions(app: SphinxTestApp) -> None:
     text = '.. program:: cmd\n\n.. option:: -o directory, --output directory\n'
     domain = app.env.domains.standard_domain
     doctree = restructuredtext.parse(app, text)
@@ -479,86 +485,12 @@ def test_multiple_cmdoptions(app):
     )
     assert ('cmd', '-o') in domain.progoptions
     assert ('cmd', '--output') in domain.progoptions
-    assert domain.progoptions[('cmd', '-o')] == ('index', 'cmdoption-cmd-o')
-    assert domain.progoptions[('cmd', '--output')] == ('index', 'cmdoption-cmd-o')
+    assert domain.progoptions['cmd', '-o'] == ('index', 'cmdoption-cmd-o')
+    assert domain.progoptions['cmd', '--output'] == ('index', 'cmdoption-cmd-o')
 
 
-@pytest.mark.sphinx('html', testroot='productionlist')
-def test_productionlist(app):
-    app.build(force_all=True)
-
-    warnings = app.warning.getvalue().split('\n')
-    assert len(warnings) == 2
-    assert warnings[-1] == ''
-    assert (
-        'Dup2.rst:4: WARNING: duplicate token description of Dup, other instance in Dup1'
-        in warnings[0]
-    )
-
-    etree = etree_parse(app.outdir / 'index.html')
-    nodes = list(etree.iter('ul'))
-    assert len(nodes) >= 3
-
-    ul = nodes[2]
-    cases = []
-    for li in list(ul):
-        assert len(list(li)) == 1
-        p = list(li)[0]
-        assert p.tag == 'p'
-        text = str(p.text).strip(' :')
-        assert len(list(p)) == 1
-        a = list(p)[0]
-        assert a.tag == 'a'
-        link = a.get('href')
-        assert len(list(a)) == 1
-        code = list(a)[0]
-        assert code.tag == 'code'
-        assert len(list(code)) == 1
-        span = list(code)[0]
-        assert span.tag == 'span'
-        linkText = span.text.strip()
-        cases.append((text, link, linkText))
-    assert cases == [
-        ('A', 'Bare.html#grammar-token-A', 'A'),
-        ('B', 'Bare.html#grammar-token-B', 'B'),
-        ('P1:A', 'P1.html#grammar-token-P1-A', 'P1:A'),
-        ('P1:B', 'P1.html#grammar-token-P1-B', 'P1:B'),
-        ('P2:A', 'P1.html#grammar-token-P1-A', 'P1:A'),
-        ('P2:B', 'P2.html#grammar-token-P2-B', 'P2:B'),
-        ('Explicit title A, plain', 'Bare.html#grammar-token-A', 'MyTitle'),
-        ('Explicit title A, colon', 'Bare.html#grammar-token-A', 'My:Title'),
-        ('Explicit title P1:A, plain', 'P1.html#grammar-token-P1-A', 'MyTitle'),
-        ('Explicit title P1:A, colon', 'P1.html#grammar-token-P1-A', 'My:Title'),
-        ('Tilde A', 'Bare.html#grammar-token-A', 'A'),
-        ('Tilde P1:A', 'P1.html#grammar-token-P1-A', 'A'),
-        ('Tilde explicit title P1:A', 'P1.html#grammar-token-P1-A', '~MyTitle'),
-        ('Tilde, explicit title P1:A', 'P1.html#grammar-token-P1-A', 'MyTitle'),
-        ('Dup', 'Dup2.html#grammar-token-Dup', 'Dup'),
-        ('FirstLine', 'firstLineRule.html#grammar-token-FirstLine', 'FirstLine'),
-        ('SecondLine', 'firstLineRule.html#grammar-token-SecondLine', 'SecondLine'),
-    ]
-
-    text = (app.outdir / 'LineContinuation.html').read_text(encoding='utf8')
-    assert 'A</strong> ::=  B C D    E F G' in text
-
-
-@pytest.mark.sphinx('html', testroot='root')
-def test_productionlist2(app):
-    text = '.. productionlist:: P2\n   A: `:A` `A`\n   B: `P1:B` `~P1:B`\n'
-    doctree = restructuredtext.parse(app, text)
-    refnodes = list(doctree.findall(pending_xref))
-    assert_node(refnodes[0], pending_xref, reftarget='A')
-    assert_node(refnodes[1], pending_xref, reftarget='P2:A')
-    assert_node(refnodes[2], pending_xref, reftarget='P1:B')
-    assert_node(refnodes[3], pending_xref, reftarget='P1:B')
-    assert_node(refnodes[0], [pending_xref, nodes.literal, 'A'])
-    assert_node(refnodes[1], [pending_xref, nodes.literal, 'A'])
-    assert_node(refnodes[2], [pending_xref, nodes.literal, 'P1:B'])
-    assert_node(refnodes[3], [pending_xref, nodes.literal, 'B'])
-
-
-@pytest.mark.sphinx('html', testroot='root')
-def test_disabled_docref(app):
+@pytest.mark.sphinx('html', testroot='_blank')
+def test_disabled_docref(app: SphinxTestApp) -> None:
     text = ':doc:`index`\n:doc:`!index`\n'
     doctree = restructuredtext.parse(app, text)
     assert_node(
@@ -572,8 +504,8 @@ def test_disabled_docref(app):
     )
 
 
-@pytest.mark.sphinx('html', testroot='root')
-def test_labeled_rubric(app):
+@pytest.mark.sphinx('html', testroot='_blank')
+def test_labeled_rubric(app: SphinxTestApp) -> None:
     text = '.. _label:\n.. rubric:: blah *blah* blah\n'
     restructuredtext.parse(app, text)
 
@@ -582,8 +514,8 @@ def test_labeled_rubric(app):
     assert domain.labels['label'] == ('index', 'label', 'blah blah blah')
 
 
-@pytest.mark.sphinx('html', testroot='root')
-def test_labeled_definition(app):
+@pytest.mark.sphinx('html', testroot='_blank')
+def test_labeled_definition(app: SphinxTestApp) -> None:
     text = (
         '.. _label1:\n'
         '\n'
@@ -605,8 +537,8 @@ def test_labeled_definition(app):
     assert domain.labels['label2'] == ('index', 'label2', 'Bar blah blah blah')
 
 
-@pytest.mark.sphinx('html', testroot='root')
-def test_labeled_field(app):
+@pytest.mark.sphinx('html', testroot='_blank')
+def test_labeled_field(app: SphinxTestApp) -> None:
     text = (
         '.. _label1:\n'
         '\n'
@@ -633,7 +565,7 @@ def test_labeled_field(app):
     testroot='manpage_url',
     confoverrides={'manpages_url': 'https://example.com/{page}.{section}'},
 )
-def test_html_manpage(app):
+def test_html_manpage(app: SphinxTestApp) -> None:
     app.build(force_all=True)
 
     content = (app.outdir / 'index.html').read_text(encoding='utf8')
