@@ -1,12 +1,13 @@
 """Test module for napoleon PEP 526 compatibility with numpy style"""
 
+from __future__ import annotations
+
 module_level_var: int = 99
 """This is an example module level variable"""
 
 
 class PEP526NumpyClass:
-    """
-    Sample class with PEP 526 annotations and numpy docstring
+    """Sample class with PEP 526 annotations and numpy docstring
 
     Attributes
     ----------
