@@ -1,13 +1,21 @@
 """Test the sphinx.apidoc module."""
 
-import os.path
+from __future__ import annotations
+
 from collections import namedtuple
-from pathlib import Path
+from typing import TYPE_CHECKING
 
 import pytest
 
-import sphinx.ext.apidoc
-from sphinx.ext.apidoc import main as apidoc_main
+import sphinx.ext.apidoc._generate
+from sphinx.ext.apidoc._cli import main as apidoc_main
+
+if TYPE_CHECKING:
+    from pathlib import Path
+
+    from sphinx.testing.util import SphinxTestApp
+
+_apidoc = namedtuple('_apidoc', 'coderoot,outdir')  # NoQA: PYI024
 
 
 @pytest.fixture
@@ -25,7 +33,7 @@ def apidoc(rootdir, tmp_path, apidoc_params):
         *kwargs.get('options', []),
     ]
     apidoc_main(args)
-    return namedtuple('apidoc', 'coderoot,outdir')(coderoot, outdir)
+    return _apidoc(coderoot, outdir)
 
 
 @pytest.fixture
@@ -54,10 +62,10 @@ def test_simple(make_app, apidoc):
 
 
 @pytest.mark.apidoc(
-    coderoot='test-apidoc-custom-templates',
+    coderoot='test-ext-apidoc-custom-templates',
     options=[
         '--separate',
-        '--templatedir=tests/roots/test-apidoc-custom-templates/_templates',
+        '--templatedir=tests/roots/test-ext-apidoc-custom-templates/_templates',
     ],
 )
 def test_custom_templates(make_app, apidoc):
@@ -80,16 +88,16 @@ def test_custom_templates(make_app, apidoc):
     # Assert that the legacy filename is discovered
     with open(builddir / 'mypackage.txt', encoding='utf-8') as f:
         txt = f.read()
-        assert 'The legacy package template was found!' in txt
+    assert 'The legacy package template was found!' in txt
 
     # Assert that the new filename is preferred
     with open(builddir / 'mypackage.mymodule.txt', encoding='utf-8') as f:
         txt = f.read()
-        assert 'The Jinja module template was found!' in txt
+    assert 'The Jinja module template was found!' in txt
 
 
 @pytest.mark.apidoc(
-    coderoot='test-apidoc-pep420/a',
+    coderoot='test-ext-apidoc-pep420/a',
     options=['--implicit-namespaces'],
 )
 def test_pep_0420_enabled(make_app, apidoc):
@@ -101,17 +109,17 @@ def test_pep_0420_enabled(make_app, apidoc):
 
     with open(outdir / 'a.b.c.rst', encoding='utf-8') as f:
         rst = f.read()
-        assert 'automodule:: a.b.c.d\n' in rst
-        assert 'automodule:: a.b.c\n' in rst
+    assert 'automodule:: a.b.c.d\n' in rst
+    assert 'automodule:: a.b.c\n' in rst
 
     with open(outdir / 'a.b.e.rst', encoding='utf-8') as f:
         rst = f.read()
-        assert 'automodule:: a.b.e.f\n' in rst
+    assert 'automodule:: a.b.e.f\n' in rst
 
     with open(outdir / 'a.b.x.rst', encoding='utf-8') as f:
         rst = f.read()
-        assert 'automodule:: a.b.x.y\n' in rst
-        assert 'automodule:: a.b.x\n' not in rst
+    assert 'automodule:: a.b.x.y\n' in rst
+    assert 'automodule:: a.b.x\n' not in rst
 
     app = make_app('text', srcdir=outdir)
     app.build()
@@ -125,19 +133,19 @@ def test_pep_0420_enabled(make_app, apidoc):
 
     with open(builddir / 'a.b.c.txt', encoding='utf-8') as f:
         txt = f.read()
-        assert 'a.b.c package\n' in txt
+    assert 'a.b.c package\n' in txt
 
     with open(builddir / 'a.b.e.txt', encoding='utf-8') as f:
         txt = f.read()
-        assert 'a.b.e.f module\n' in txt
+    assert 'a.b.e.f module\n' in txt
 
     with open(builddir / 'a.b.x.txt', encoding='utf-8') as f:
         txt = f.read()
-        assert 'a.b.x namespace\n' in txt
+    assert 'a.b.x namespace\n' in txt
 
 
 @pytest.mark.apidoc(
-    coderoot='test-apidoc-pep420/a',
+    coderoot='test-ext-apidoc-pep420/a',
     options=['--implicit-namespaces', '--separate'],
 )
 def test_pep_0420_enabled_separate(make_app, apidoc):
@@ -151,15 +159,15 @@ def test_pep_0420_enabled_separate(make_app, apidoc):
 
     with open(outdir / 'a.b.c.rst', encoding='utf-8') as f:
         rst = f.read()
-        assert '.. toctree::\n   :maxdepth: 4\n\n   a.b.c.d\n' in rst
+    assert '.. toctree::\n   :maxdepth: 4\n\n   a.b.c.d\n' in rst
 
     with open(outdir / 'a.b.e.rst', encoding='utf-8') as f:
         rst = f.read()
-        assert '.. toctree::\n   :maxdepth: 4\n\n   a.b.e.f\n' in rst
+    assert '.. toctree::\n   :maxdepth: 4\n\n   a.b.e.f\n' in rst
 
     with open(outdir / 'a.b.x.rst', encoding='utf-8') as f:
         rst = f.read()
-        assert '.. toctree::\n   :maxdepth: 4\n\n   a.b.x.y\n' in rst
+    assert '.. toctree::\n   :maxdepth: 4\n\n   a.b.x.y\n' in rst
 
     app = make_app('text', srcdir=outdir)
     app.build()
@@ -175,18 +183,18 @@ def test_pep_0420_enabled_separate(make_app, apidoc):
 
     with open(builddir / 'a.b.c.txt', encoding='utf-8') as f:
         txt = f.read()
-        assert 'a.b.c package\n' in txt
+    assert 'a.b.c package\n' in txt
 
     with open(builddir / 'a.b.e.f.txt', encoding='utf-8') as f:
         txt = f.read()
-        assert 'a.b.e.f module\n' in txt
+    assert 'a.b.e.f module\n' in txt
 
     with open(builddir / 'a.b.x.txt', encoding='utf-8') as f:
         txt = f.read()
-        assert 'a.b.x namespace\n' in txt
+    assert 'a.b.x namespace\n' in txt
 
 
-@pytest.mark.apidoc(coderoot='test-apidoc-pep420/a')
+@pytest.mark.apidoc(coderoot='test-ext-apidoc-pep420/a')
 def test_pep_0420_disabled(make_app, apidoc):
     outdir = apidoc.outdir
     assert (outdir / 'conf.py').is_file()
@@ -199,7 +207,7 @@ def test_pep_0420_disabled(make_app, apidoc):
     print(app._warning.getvalue())
 
 
-@pytest.mark.apidoc(coderoot='test-apidoc-pep420/a/b')
+@pytest.mark.apidoc(coderoot='test-ext-apidoc-pep420/a/b')
 def test_pep_0420_disabled_top_level_verify(make_app, apidoc):
     outdir = apidoc.outdir
     assert (outdir / 'conf.py').is_file()
@@ -208,9 +216,9 @@ def test_pep_0420_disabled_top_level_verify(make_app, apidoc):
 
     with open(outdir / 'c.rst', encoding='utf-8') as f:
         rst = f.read()
-        assert 'c package\n' in rst
-        assert 'automodule:: c.d\n' in rst
-        assert 'automodule:: c\n' in rst
+    assert 'c package\n' in rst
+    assert 'automodule:: c.d\n' in rst
+    assert 'automodule:: c\n' in rst
 
     app = make_app('text', srcdir=outdir)
     app.build()
@@ -218,7 +226,7 @@ def test_pep_0420_disabled_top_level_verify(make_app, apidoc):
     print(app._warning.getvalue())
 
 
-@pytest.mark.apidoc(coderoot='test-apidoc-trailing-underscore')
+@pytest.mark.apidoc(coderoot='test-ext-apidoc-trailing-underscore')
 def test_trailing_underscore(make_app, apidoc):
     outdir = apidoc.outdir
     assert (outdir / 'conf.py').is_file()
@@ -232,12 +240,12 @@ def test_trailing_underscore(make_app, apidoc):
     builddir = outdir / '_build' / 'text'
     with open(builddir / 'package_.txt', encoding='utf-8') as f:
         rst = f.read()
-        assert 'package_ package\n' in rst
-        assert 'package_.module_ module\n' in rst
+    assert 'package_ package\n' in rst
+    assert 'package_.module_ module\n' in rst
 
 
 @pytest.mark.apidoc(
-    coderoot='test-apidoc-pep420/a',
+    coderoot='test-ext-apidoc-pep420/a',
     excludes=['b/c/d.py', 'b/e/f.py', 'b/e/__init__.py'],
     options=['--implicit-namespaces', '--separate'],
 )
@@ -255,7 +263,7 @@ def test_excludes(apidoc):
 
 
 @pytest.mark.apidoc(
-    coderoot='test-apidoc-pep420/a',
+    coderoot='test-ext-apidoc-pep420/a',
     excludes=['b/e'],
     options=['--implicit-namespaces', '--separate'],
 )
@@ -272,7 +280,7 @@ def test_excludes_subpackage_should_be_skipped(apidoc):
 
 
 @pytest.mark.apidoc(
-    coderoot='test-apidoc-pep420/a',
+    coderoot='test-ext-apidoc-pep420/a',
     excludes=['b/e/f.py'],
     options=['--implicit-namespaces', '--separate'],
 )
@@ -289,7 +297,7 @@ def test_excludes_module_should_be_skipped(apidoc):
 
 
 @pytest.mark.apidoc(
-    coderoot='test-apidoc-pep420/a',
+    coderoot='test-ext-apidoc-pep420/a',
     excludes=[],
     options=['--implicit-namespaces', '--separate'],
 )
@@ -343,11 +351,11 @@ def test_extension_parsed(apidoc):
 
     with open(outdir / 'conf.py', encoding='utf-8') as f:
         rst = f.read()
-        assert 'sphinx.ext.mathjax' in rst
+    assert 'sphinx.ext.mathjax' in rst
 
 
 @pytest.mark.apidoc(
-    coderoot='test-apidoc-toc/mypackage',
+    coderoot='test-ext-apidoc-toc/mypackage',
     options=['--implicit-namespaces'],
 )
 def test_toc_all_references_should_exist_pep420_enabled(apidoc):
@@ -365,7 +373,7 @@ def test_toc_all_references_should_exist_pep420_enabled(apidoc):
     found_refs = []
     missing_files = []
     for ref in refs:
-        if ref and ref[0] in (':', '#'):
+        if ref and ref[0] in {':', '#'}:
             continue
         found_refs.append(ref)
         filename = f'{ref}.rst'
@@ -373,13 +381,13 @@ def test_toc_all_references_should_exist_pep420_enabled(apidoc):
             missing_files.append(filename)
 
     all_missing = ', '.join(missing_files)
-    assert (
-        len(missing_files) == 0
-    ), f'File(s) referenced in TOC not found: {all_missing}\nTOC:\n{toc}'
+    assert len(missing_files) == 0, (
+        f'File(s) referenced in TOC not found: {all_missing}\nTOC:\n{toc}'
+    )
 
 
 @pytest.mark.apidoc(
-    coderoot='test-apidoc-toc/mypackage',
+    coderoot='test-ext-apidoc-toc/mypackage',
 )
 def test_toc_all_references_should_exist_pep420_disabled(apidoc):
     """All references in toc should exist. This test doesn't say if
@@ -396,7 +404,7 @@ def test_toc_all_references_should_exist_pep420_disabled(apidoc):
     found_refs = []
     missing_files = []
     for ref in refs:
-        if ref and ref[0] in (':', '#'):
+        if ref and ref[0] in {':', '#'}:
             continue
         filename = f'{ref}.rst'
         found_refs.append(ref)
@@ -404,9 +412,9 @@ def test_toc_all_references_should_exist_pep420_disabled(apidoc):
             missing_files.append(filename)
 
     all_missing = ', '.join(missing_files)
-    assert (
-        len(missing_files) == 0
-    ), f'File(s) referenced in TOC not found: {all_missing}\nTOC:\n{toc}'
+    assert len(missing_files) == 0, (
+        f'File(s) referenced in TOC not found: {all_missing}\nTOC:\n{toc}'
+    )
 
 
 def extract_toc(path):
@@ -426,12 +434,13 @@ def extract_toc(path):
 
 
 @pytest.mark.apidoc(
-    coderoot='test-apidoc-subpackage-in-toc',
+    coderoot='test-ext-apidoc-subpackage-in-toc',
     options=['--separate'],
 )
 def test_subpackage_in_toc(apidoc):
     """Make sure that empty subpackages with non-empty subpackages in them
-    are not skipped (issue #4520)
+    are not skipped
+    See: https://github.com/sphinx-doc/sphinx/issues/4520
     """
     outdir = apidoc.outdir
     assert (outdir / 'conf.py').is_file()
@@ -501,8 +510,8 @@ def test_module_file(tmp_path):
         '\n'
         '.. automodule:: example\n'
         '   :members:\n'
-        '   :undoc-members:\n'
         '   :show-inheritance:\n'
+        '   :undoc-members:\n'
     )
 
 
@@ -516,8 +525,8 @@ def test_module_file_noheadings(tmp_path):
     assert content == (
         '.. automodule:: example\n'
         '   :members:\n'
-        '   :undoc-members:\n'
         '   :show-inheritance:\n'
+        '   :undoc-members:\n'
     )
 
 
@@ -554,24 +563,24 @@ def test_package_file(tmp_path):
         '\n'
         '.. automodule:: testpkg.hello\n'
         '   :members:\n'
-        '   :undoc-members:\n'
         '   :show-inheritance:\n'
+        '   :undoc-members:\n'
         '\n'
         'testpkg.world module\n'
         '--------------------\n'
         '\n'
         '.. automodule:: testpkg.world\n'
         '   :members:\n'
-        '   :undoc-members:\n'
         '   :show-inheritance:\n'
+        '   :undoc-members:\n'
         '\n'
         'Module contents\n'
         '---------------\n'
         '\n'
         '.. automodule:: testpkg\n'
         '   :members:\n'
-        '   :undoc-members:\n'
         '   :show-inheritance:\n'
+        '   :undoc-members:\n'
     )
 
     content = (outdir / 'testpkg.subpkg.rst').read_text(encoding='utf8')
@@ -584,8 +593,8 @@ def test_package_file(tmp_path):
         '\n'
         '.. automodule:: testpkg.subpkg\n'
         '   :members:\n'
-        '   :undoc-members:\n'
         '   :show-inheritance:\n'
+        '   :undoc-members:\n'
     )
 
 
@@ -616,8 +625,8 @@ def test_package_file_separate(tmp_path):
         '\n'
         '.. automodule:: testpkg\n'
         '   :members:\n'
-        '   :undoc-members:\n'
         '   :show-inheritance:\n'
+        '   :undoc-members:\n'
     )
 
     content = (outdir / 'testpkg.example.rst').read_text(encoding='utf8')
@@ -627,8 +636,8 @@ def test_package_file_separate(tmp_path):
         '\n'
         '.. automodule:: testpkg.example\n'
         '   :members:\n'
-        '   :undoc-members:\n'
         '   :show-inheritance:\n'
+        '   :undoc-members:\n'
     )
 
 
@@ -646,8 +655,8 @@ def test_package_file_module_first(tmp_path):
         '\n'
         '.. automodule:: testpkg\n'
         '   :members:\n'
-        '   :undoc-members:\n'
         '   :show-inheritance:\n'
+        '   :undoc-members:\n'
         '\n'
         'Submodules\n'
         '----------\n'
@@ -657,8 +666,8 @@ def test_package_file_module_first(tmp_path):
         '\n'
         '.. automodule:: testpkg.example\n'
         '   :members:\n'
-        '   :undoc-members:\n'
         '   :show-inheritance:\n'
+        '   :undoc-members:\n'
     )
 
 
@@ -679,8 +688,8 @@ def test_package_file_without_submodules(tmp_path):
         '\n'
         '.. automodule:: testpkg\n'
         '   :members:\n'
-        '   :undoc-members:\n'
         '   :show-inheritance:\n'
+        '   :undoc-members:\n'
     )
 
 
@@ -711,8 +720,8 @@ def test_namespace_package_file(tmp_path):
         '\n'
         '.. automodule:: testpkg.example\n'
         '   :members:\n'
-        '   :undoc-members:\n'
         '   :show-inheritance:\n'
+        '   :undoc-members:\n'
     )
 
 
@@ -722,17 +731,17 @@ def test_no_duplicates(rootdir, tmp_path):
     We can't use pytest.mark.apidoc here as we use a different set of arguments
     to apidoc_main
     """
-    original_suffixes = sphinx.ext.apidoc.PY_SUFFIXES
+    original_suffixes = sphinx.ext.apidoc._generate.PY_SUFFIXES
     try:
         # Ensure test works on Windows
-        sphinx.ext.apidoc.PY_SUFFIXES += ('.so',)
+        sphinx.ext.apidoc._generate.PY_SUFFIXES += ('.so',)
 
-        package = rootdir / 'test-apidoc-duplicates' / 'fish_licence'
+        package = rootdir / 'test-ext-apidoc-duplicates' / 'fish_licence'
         outdir = tmp_path / 'out'
         apidoc_main(['-o', str(outdir), '-T', str(package), '--implicit-namespaces'])
 
         # Ensure the module has been documented
-        assert os.path.isfile(outdir / 'fish_licence.rst')
+        assert (outdir / 'fish_licence.rst').is_file()
 
         # Ensure the submodule only appears once
         text = (outdir / 'fish_licence.rst').read_text(encoding='utf-8')
@@ -740,7 +749,7 @@ def test_no_duplicates(rootdir, tmp_path):
         assert count_submodules == 1
 
     finally:
-        sphinx.ext.apidoc.PY_SUFFIXES = original_suffixes
+        sphinx.ext.apidoc._generate.PY_SUFFIXES = original_suffixes
 
 
 def test_remove_old_files(tmp_path: Path):
@@ -765,3 +774,27 @@ def test_remove_old_files(tmp_path: Path):
     apidoc_main(['--remove-old', '-o', str(gen_dir), str(module_dir)])
     assert set(gen_dir.iterdir()) == {gen_dir / 'modules.rst', gen_dir / 'example.rst'}
     assert (gen_dir / 'example.rst').stat().st_mtime_ns == example_mtime
+
+
+@pytest.mark.sphinx(testroot='ext-apidoc')
+def test_sphinx_extension(app: SphinxTestApp) -> None:
+    """Test running apidoc as an extension."""
+    app.build()
+    assert app.warning.getvalue() == ''
+
+    toc_file = app.srcdir / 'generated' / 'modules.rst'
+    pkg_file = app.srcdir / 'generated' / 'my_package.rst'
+    assert set((app.srcdir / 'generated').iterdir()) == {toc_file, pkg_file}
+    modules_content = toc_file.read_text(encoding='utf8')
+    assert modules_content == (
+        'src\n===\n\n.. toctree::\n   :maxdepth: 3\n\n   my_package\n'
+    )
+    assert 'show-inheritance' not in pkg_file.read_text(encoding='utf8')
+    assert (app.outdir / 'generated' / 'my_package.html').is_file()
+
+    # test a re-build
+    app.build()
+    assert app.warning.getvalue() == ''
+
+    # TODO check nothing got re-built
+    # TODO test that old files are removed
