@@ -1,8 +1,11 @@
 """Test the autodoc extension.  This tests mainly for config variables"""
 
+from __future__ import annotations
+
 import platform
 import sys
 from contextlib import contextmanager
+from typing import TYPE_CHECKING
 
 import pytest
 
@@ -10,11 +13,17 @@ from sphinx.testing import restructuredtext
 
 from tests.test_extensions.autodoc_util import do_autodoc
 
+if TYPE_CHECKING:
+    from collections.abc import Iterator
+    from pathlib import Path
+
+    from sphinx.testing.util import SphinxTestApp
+
 IS_PYPY = platform.python_implementation() == 'PyPy'
 
 
 @contextmanager
-def overwrite_file(path, content):
+def overwrite_file(path: Path, content: str) -> Iterator[None]:
     current_content = path.read_bytes() if path.exists() else None
     try:
         path.write_text(content, encoding='utf-8')
@@ -27,7 +36,7 @@ def overwrite_file(path, content):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autoclass_content_class(app):
+def test_autoclass_content_class(app: SphinxTestApp) -> None:
     app.config.autoclass_content = 'class'
     options = {'members': None}
     actual = do_autodoc(app, 'module', 'target.autoclass_content', options)
@@ -87,7 +96,7 @@ def test_autoclass_content_class(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autoclass_content_init(app):
+def test_autoclass_content_init(app: SphinxTestApp) -> None:
     app.config.autoclass_content = 'init'
     options = {'members': None}
     actual = do_autodoc(app, 'module', 'target.autoclass_content', options)
@@ -147,7 +156,7 @@ def test_autoclass_content_init(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autodoc_class_signature_mixed(app):
+def test_autodoc_class_signature_mixed(app: SphinxTestApp) -> None:
     app.config.autodoc_class_signature = 'mixed'
     options = {
         'members': None,
@@ -163,7 +172,7 @@ def test_autodoc_class_signature_mixed(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autodoc_class_signature_separated_init(app):
+def test_autodoc_class_signature_separated_init(app: SphinxTestApp) -> None:
     app.config.autodoc_class_signature = 'separated'
     options = {
         'members': None,
@@ -183,7 +192,7 @@ def test_autodoc_class_signature_separated_init(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autodoc_class_signature_separated_new(app):
+def test_autodoc_class_signature_separated_new(app: SphinxTestApp) -> None:
     app.config.autodoc_class_signature = 'separated'
     options = {
         'members': None,
@@ -204,7 +213,7 @@ def test_autodoc_class_signature_separated_new(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autoclass_content_both(app):
+def test_autoclass_content_both(app: SphinxTestApp) -> None:
     app.config.autoclass_content = 'both'
     options = {'members': None}
     actual = do_autodoc(app, 'module', 'target.autoclass_content', options)
@@ -274,7 +283,7 @@ def test_autoclass_content_both(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autodoc_inherit_docstrings(app):
+def test_autodoc_inherit_docstrings(app: SphinxTestApp) -> None:
     assert app.config.autodoc_inherit_docstrings is True  # default
     actual = do_autodoc(app, 'method', 'target.inheritance.Derived.inheritedmeth')
     assert list(actual) == [
@@ -298,7 +307,7 @@ def test_autodoc_inherit_docstrings(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autodoc_inherit_docstrings_for_inherited_members(app):
+def test_autodoc_inherit_docstrings_for_inherited_members(app: SphinxTestApp) -> None:
     options = {
         'members': None,
         'inherited-members': None,
@@ -312,6 +321,12 @@ def test_autodoc_inherit_docstrings_for_inherited_members(app):
         '   :module: target.inheritance',
         '',
         '',
+        '   .. py:method:: Derived.another_inheritedmeth()',
+        '      :module: target.inheritance',
+        '',
+        '      Another inherited function.',
+        '',
+        '',
         '   .. py:attribute:: Derived.inheritedattr',
         '      :module: target.inheritance',
         '      :value: None',
@@ -349,6 +364,12 @@ def test_autodoc_inherit_docstrings_for_inherited_members(app):
         '   :module: target.inheritance',
         '',
         '',
+        '   .. py:method:: Derived.another_inheritedmeth()',
+        '      :module: target.inheritance',
+        '',
+        '      Another inherited function.',
+        '',
+        '',
         '   .. py:method:: Derived.inheritedclassmeth()',
         '      :module: target.inheritance',
         '      :classmethod:',
@@ -366,7 +387,7 @@ def test_autodoc_inherit_docstrings_for_inherited_members(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autodoc_docstring_signature(app):
+def test_autodoc_docstring_signature(app: SphinxTestApp) -> None:
     options = {'members': None, 'special-members': '__init__, __new__'}
     actual = do_autodoc(app, 'class', 'target.DocstringSig', options)
     assert list(actual) == [
@@ -441,8 +462,7 @@ def test_autodoc_docstring_signature(app):
         '      __init__(self, a, b=1) -> None',
         '      First line of docstring',
         '',
-        '              rest of docstring',
-        '',
+        '      rest of docstring',
         '',
         '',
         '   .. py:method:: DocstringSig.__new__(cls, *new_args, **new_kwargs)',
@@ -452,8 +472,7 @@ def test_autodoc_docstring_signature(app):
         '      __new__(cls, d, e=1) -> DocstringSig',
         '      First line of docstring',
         '',
-        '              rest of docstring',
-        '',
+        '      rest of docstring',
         '',
         '',
         '   .. py:method:: DocstringSig.meth()',
@@ -462,8 +481,7 @@ def test_autodoc_docstring_signature(app):
         '      meth(FOO, BAR=1) -> BAZ',
         '      First line of docstring',
         '',
-        '              rest of docstring',
-        '',
+        '      rest of docstring',
         '',
         '',
         '   .. py:method:: DocstringSig.meth2()',
@@ -492,7 +510,7 @@ def test_autodoc_docstring_signature(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autoclass_content_and_docstring_signature_class(app):
+def test_autoclass_content_and_docstring_signature_class(app: SphinxTestApp) -> None:
     app.config.autoclass_content = 'class'
     options = {
         'members': None,
@@ -531,7 +549,7 @@ def test_autoclass_content_and_docstring_signature_class(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autoclass_content_and_docstring_signature_init(app):
+def test_autoclass_content_and_docstring_signature_init(app: SphinxTestApp) -> None:
     app.config.autoclass_content = 'init'
     options = {
         'members': None,
@@ -574,7 +592,7 @@ def test_autoclass_content_and_docstring_signature_init(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autoclass_content_and_docstring_signature_both(app):
+def test_autoclass_content_and_docstring_signature_both(app: SphinxTestApp) -> None:
     app.config.autoclass_content = 'both'
     options = {
         'members': None,
@@ -622,11 +640,11 @@ def test_autoclass_content_and_docstring_signature_both(app):
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
 @pytest.mark.usefixtures('rollback_sysmodules')
-def test_mocked_module_imports(app):
+def test_mocked_module_imports(app: SphinxTestApp) -> None:
     sys.modules.pop('target', None)  # unload target module to clear the module cache
 
     # no autodoc_mock_imports
-    options = {'members': 'TestAutodoc,decoratedFunction,func,Alias'}
+    options = {'members': 'TestAutodoc,decorated_function,func,Alias'}
     actual = do_autodoc(app, 'module', 'target.need_mocks', options)
     assert list(actual) == []
     assert "autodoc: failed to import module 'need_mocks'" in app.warning.getvalue()
@@ -665,16 +683,16 @@ def test_mocked_module_imports(app):
         '      docstring',
         '',
         '',
-        '   .. py:method:: TestAutodoc.decoratedMethod()',
+        '   .. py:method:: TestAutodoc.decorated_method()',
         '      :module: target.need_mocks',
         '',
-        '      TestAutodoc::decoratedMethod docstring',
+        '      TestAutodoc::decorated_method docstring',
         '',
         '',
-        '.. py:function:: decoratedFunction()',
+        '.. py:function:: decorated_function()',
         '   :module: target.need_mocks',
         '',
-        '   decoratedFunction docstring',
+        '   decorated_function docstring',
         '',
         '',
         '.. py:function:: func(arg: missing_module.Class)',
@@ -691,16 +709,7 @@ def test_mocked_module_imports(app):
     testroot='ext-autodoc',
     confoverrides={'autodoc_typehints': 'signature'},
 )
-def test_autodoc_typehints_signature(app):
-    if sys.version_info[:2] <= (3, 10):
-        type_o = '~typing.Any | None'
-    else:
-        type_o = '~typing.Any'
-    if sys.version_info[:2] >= (3, 13):
-        type_ppp = 'pathlib._local.PurePosixPath'
-    else:
-        type_ppp = 'pathlib.PurePosixPath'
-
+def test_autodoc_typehints_signature(app: SphinxTestApp) -> None:
     options = {
         'members': None,
         'undoc-members': None,
@@ -726,13 +735,13 @@ def test_autodoc_typehints_signature(app):
         '',
         '.. py:data:: CONST3',
         '   :module: target.typehints',
-        f'   :type: ~{type_ppp}',
+        '   :type: ~pathlib.PurePosixPath',
         "   :value: PurePosixPath('/a/b/c')",
         '',
         '   docstring',
         '',
         '',
-        '.. py:class:: Math(s: str, o: %s = None)' % type_o,
+        '.. py:class:: Math(s: str, o: ~typing.Any = None)',
         '   :module: target.typehints',
         '',
         '',
@@ -749,7 +758,7 @@ def test_autodoc_typehints_signature(app):
         '',
         '   .. py:attribute:: Math.CONST3',
         '      :module: target.typehints',
-        f'      :type: ~{type_ppp}',
+        '      :type: ~pathlib.PurePosixPath',
         "      :value: PurePosixPath('/a/b/c')",
         '',
         '',
@@ -771,7 +780,7 @@ def test_autodoc_typehints_signature(app):
         '',
         '   .. py:property:: Math.path',
         '      :module: target.typehints',
-        f'      :type: ~{type_ppp}',
+        '      :type: ~pathlib.PurePosixPath',
         '',
         '',
         '   .. py:property:: Math.prop',
@@ -796,7 +805,7 @@ def test_autodoc_typehints_signature(app):
         '',
         '   docstring',
         '',
-        f"   alias of TypeVar('T', bound=\\ :py:class:`~{type_ppp}`)",
+        "   alias of TypeVar('T', bound=\\ :py:class:`~pathlib.PurePosixPath`)",
         '',
         '',
         '.. py:function:: complex_func(arg1: str, arg2: List[int], arg3: Tuple[int, '
@@ -827,11 +836,7 @@ def test_autodoc_typehints_signature(app):
     testroot='ext-autodoc',
     confoverrides={'autodoc_typehints': 'none'},
 )
-def test_autodoc_typehints_none(app):
-    if sys.version_info[:2] >= (3, 13):
-        type_ppp = 'pathlib._local.PurePosixPath'
-    else:
-        type_ppp = 'pathlib.PurePosixPath'
+def test_autodoc_typehints_none(app: SphinxTestApp) -> None:
     options = {
         'members': None,
         'undoc-members': None,
@@ -919,7 +924,7 @@ def test_autodoc_typehints_none(app):
         '',
         '   docstring',
         '',
-        f"   alias of TypeVar('T', bound=\\ :py:class:`~{type_ppp}`)",
+        "   alias of TypeVar('T', bound=\\ :py:class:`~pathlib.PurePosixPath`)",
         '',
         '',
         '.. py:function:: complex_func(arg1, arg2, arg3=None, *args, **kwargs)',
@@ -949,7 +954,7 @@ def test_autodoc_typehints_none(app):
     testroot='ext-autodoc',
     confoverrides={'autodoc_typehints': 'none'},
 )
-def test_autodoc_typehints_none_for_overload(app):
+def test_autodoc_typehints_none_for_overload(app: SphinxTestApp) -> None:
     options = {'members': None}
     actual = do_autodoc(app, 'module', 'target.overload', options)
     assert list(actual) == [
@@ -1001,7 +1006,7 @@ def test_autodoc_typehints_none_for_overload(app):
     confoverrides={'autodoc_typehints': 'description'},
     freshenv=True,
 )
-def test_autodoc_typehints_description(app):
+def test_autodoc_typehints_description(app: SphinxTestApp) -> None:
     app.build()
     context = (app.outdir / 'index.txt').read_text(encoding='utf8')
     assert (
@@ -1042,8 +1047,9 @@ def test_autodoc_typehints_description(app):
         'autodoc_typehints': 'description',
         'autodoc_typehints_description_target': 'documented',
     },
+    copy_test_root=True,
 )
-def test_autodoc_typehints_description_no_undoc(app):
+def test_autodoc_typehints_description_no_undoc(app: SphinxTestApp) -> None:
     # No :type: or :rtype: will be injected for `incr`, which does not have
     # a description for its parameters or its return. `tuple_args` does
     # describe them, so :type: and :rtype: will be added.
@@ -1094,8 +1100,9 @@ def test_autodoc_typehints_description_no_undoc(app):
         'autodoc_typehints': 'description',
         'autodoc_typehints_description_target': 'documented_params',
     },
+    copy_test_root=True,
 )
-def test_autodoc_typehints_description_no_undoc_doc_rtype(app):
+def test_autodoc_typehints_description_no_undoc_doc_rtype(app: SphinxTestApp) -> None:
     # No :type: will be injected for `incr`, which does not have a description
     # for its parameters or its return, just :rtype: will be injected due to
     # autodoc_typehints_description_target. `tuple_args` does describe both, so
@@ -1163,8 +1170,9 @@ def test_autodoc_typehints_description_no_undoc_doc_rtype(app):
     'text',
     testroot='ext-autodoc',
     confoverrides={'autodoc_typehints': 'description'},
+    copy_test_root=True,
 )
-def test_autodoc_typehints_description_with_documented_init(app):
+def test_autodoc_typehints_description_with_documented_init(app: SphinxTestApp) -> None:
     with overwrite_file(
         app.srcdir / 'index.rst',
         '.. autoclass:: target.typehints._ClassWithDocumentedInit\n'
@@ -1207,8 +1215,11 @@ def test_autodoc_typehints_description_with_documented_init(app):
         'autodoc_typehints': 'description',
         'autodoc_typehints_description_target': 'documented',
     },
+    copy_test_root=True,
 )
-def test_autodoc_typehints_description_with_documented_init_no_undoc(app):
+def test_autodoc_typehints_description_with_documented_init_no_undoc(
+    app: SphinxTestApp,
+) -> None:
     with overwrite_file(
         app.srcdir / 'index.rst',
         '.. autoclass:: target.typehints._ClassWithDocumentedInit\n'
@@ -1241,8 +1252,11 @@ def test_autodoc_typehints_description_with_documented_init_no_undoc(app):
         'autodoc_typehints': 'description',
         'autodoc_typehints_description_target': 'documented_params',
     },
+    copy_test_root=True,
 )
-def test_autodoc_typehints_description_with_documented_init_no_undoc_doc_rtype(app):
+def test_autodoc_typehints_description_with_documented_init_no_undoc_doc_rtype(
+    app: SphinxTestApp,
+) -> None:
     # see test_autodoc_typehints_description_with_documented_init_no_undoc
     # returnvalue_and_documented_params should not change class or method
     # docstring.
@@ -1276,7 +1290,7 @@ def test_autodoc_typehints_description_with_documented_init_no_undoc_doc_rtype(a
     testroot='ext-autodoc',
     confoverrides={'autodoc_typehints': 'description'},
 )
-def test_autodoc_typehints_description_for_invalid_node(app):
+def test_autodoc_typehints_description_for_invalid_node(app: SphinxTestApp) -> None:
     text = '.. py:function:: hello; world'
     restructuredtext.parse(app, text)  # raises no error
 
@@ -1285,8 +1299,9 @@ def test_autodoc_typehints_description_for_invalid_node(app):
     'text',
     testroot='ext-autodoc',
     confoverrides={'autodoc_typehints': 'both'},
+    copy_test_root=True,
 )
-def test_autodoc_typehints_both(app):
+def test_autodoc_typehints_both(app: SphinxTestApp) -> None:
     with overwrite_file(
         app.srcdir / 'index.rst',
         '.. autofunction:: target.typehints.incr\n'
@@ -1329,7 +1344,7 @@ def test_autodoc_typehints_both(app):
 
 
 @pytest.mark.sphinx('text', testroot='ext-autodoc')
-def test_autodoc_type_aliases(app):
+def test_autodoc_type_aliases(app: SphinxTestApp) -> None:
     # default
     options = {'members': None}
     actual = do_autodoc(app, 'module', 'target.autodoc_type_aliases', options)
@@ -1365,7 +1380,7 @@ def test_autodoc_type_aliases(app):
         '   docstring',
         '',
         '',
-        '.. py:function:: read(r: ~_io.BytesIO) -> ~_io.StringIO',
+        '.. py:function:: read(r: ~io.BytesIO) -> ~io.StringIO',
         '   :module: target.autodoc_type_aliases',
         '',
         '   docstring',
@@ -1438,7 +1453,7 @@ def test_autodoc_type_aliases(app):
         '   docstring',
         '',
         '',
-        '.. py:function:: read(r: ~_io.BytesIO) -> my.module.StringIO',
+        '.. py:function:: read(r: ~io.BytesIO) -> my.module.StringIO',
         '   :module: target.autodoc_type_aliases',
         '',
         '   docstring',
@@ -1483,7 +1498,7 @@ def test_autodoc_type_aliases(app):
         'autodoc_type_aliases': {'myint': 'myint'},
     },
 )
-def test_autodoc_typehints_description_and_type_aliases(app):
+def test_autodoc_typehints_description_and_type_aliases(app: SphinxTestApp) -> None:
     with overwrite_file(
         app.srcdir / 'autodoc_type_aliases.rst',
         '.. autofunction:: target.autodoc_type_aliases.sum',
@@ -1510,15 +1525,7 @@ def test_autodoc_typehints_description_and_type_aliases(app):
     testroot='ext-autodoc',
     confoverrides={'autodoc_typehints_format': 'fully-qualified'},
 )
-def test_autodoc_typehints_format_fully_qualified(app):
-    if sys.version_info[:2] <= (3, 10):
-        type_o = 'typing.Any | None'
-    else:
-        type_o = 'typing.Any'
-    if sys.version_info[:2] >= (3, 13):
-        type_ppp = 'pathlib._local.PurePosixPath'
-    else:
-        type_ppp = 'pathlib.PurePosixPath'
+def test_autodoc_typehints_format_fully_qualified(app: SphinxTestApp) -> None:
     options = {
         'members': None,
         'undoc-members': None,
@@ -1544,13 +1551,13 @@ def test_autodoc_typehints_format_fully_qualified(app):
         '',
         '.. py:data:: CONST3',
         '   :module: target.typehints',
-        f'   :type: {type_ppp}',
+        '   :type: pathlib.PurePosixPath',
         "   :value: PurePosixPath('/a/b/c')",
         '',
         '   docstring',
         '',
         '',
-        '.. py:class:: Math(s: str, o: %s = None)' % type_o,
+        '.. py:class:: Math(s: str, o: typing.Any = None)',
         '   :module: target.typehints',
         '',
         '',
@@ -1567,7 +1574,7 @@ def test_autodoc_typehints_format_fully_qualified(app):
         '',
         '   .. py:attribute:: Math.CONST3',
         '      :module: target.typehints',
-        f'      :type: {type_ppp}',
+        '      :type: pathlib.PurePosixPath',
         "      :value: PurePosixPath('/a/b/c')",
         '',
         '',
@@ -1589,7 +1596,7 @@ def test_autodoc_typehints_format_fully_qualified(app):
         '',
         '   .. py:property:: Math.path',
         '      :module: target.typehints',
-        f'      :type: {type_ppp}',
+        '      :type: pathlib.PurePosixPath',
         '',
         '',
         '   .. py:property:: Math.prop',
@@ -1614,7 +1621,7 @@ def test_autodoc_typehints_format_fully_qualified(app):
         '',
         '   docstring',
         '',
-        f"   alias of TypeVar('T', bound=\\ :py:class:`{type_ppp}`)",
+        "   alias of TypeVar('T', bound=\\ :py:class:`pathlib.PurePosixPath`)",
         '',
         '',
         '.. py:function:: complex_func(arg1: str, arg2: List[int], arg3: Tuple[int, '
@@ -1645,7 +1652,9 @@ def test_autodoc_typehints_format_fully_qualified(app):
     testroot='ext-autodoc',
     confoverrides={'autodoc_typehints_format': 'fully-qualified'},
 )
-def test_autodoc_typehints_format_fully_qualified_for_class_alias(app):
+def test_autodoc_typehints_format_fully_qualified_for_class_alias(
+    app: SphinxTestApp,
+) -> None:
     actual = do_autodoc(app, 'class', 'target.classes.Alias')
     assert list(actual) == [
         '',
@@ -1661,7 +1670,9 @@ def test_autodoc_typehints_format_fully_qualified_for_class_alias(app):
     testroot='ext-autodoc',
     confoverrides={'autodoc_typehints_format': 'fully-qualified'},
 )
-def test_autodoc_typehints_format_fully_qualified_for_generic_alias(app):
+def test_autodoc_typehints_format_fully_qualified_for_generic_alias(
+    app: SphinxTestApp,
+) -> None:
     actual = do_autodoc(app, 'data', 'target.genericalias.L')
     assert list(actual) == [
         '',
@@ -1680,7 +1691,9 @@ def test_autodoc_typehints_format_fully_qualified_for_generic_alias(app):
     testroot='ext-autodoc',
     confoverrides={'autodoc_typehints_format': 'fully-qualified'},
 )
-def test_autodoc_typehints_format_fully_qualified_for_newtype_alias(app):
+def test_autodoc_typehints_format_fully_qualified_for_newtype_alias(
+    app: SphinxTestApp,
+) -> None:
     actual = do_autodoc(app, 'class', 'target.typevar.T6')
     assert list(actual) == [
         '',
@@ -1695,11 +1708,11 @@ def test_autodoc_typehints_format_fully_qualified_for_newtype_alias(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autodoc_default_options(app):
+def test_autodoc_default_options(app: SphinxTestApp) -> None:
     if (3, 11, 7) <= sys.version_info < (3, 12) or sys.version_info >= (3, 12, 1):
         list_of_weak_references = '      list of weak references to the object'
     else:
-        list_of_weak_references = "      list of weak references to the object (if defined)"  # fmt: skip
+        list_of_weak_references = '      list of weak references to the object (if defined)'  # fmt: skip
 
     # no settings
     actual = do_autodoc(app, 'class', 'target.enums.EnumCls')
@@ -1774,11 +1787,11 @@ def test_autodoc_default_options(app):
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
-def test_autodoc_default_options_with_values(app):
+def test_autodoc_default_options_with_values(app: SphinxTestApp) -> None:
     if (3, 11, 7) <= sys.version_info < (3, 12) or sys.version_info >= (3, 12, 1):
         list_of_weak_references = '      list of weak references to the object'
     else:
-        list_of_weak_references = "      list of weak references to the object (if defined)"  # fmt: skip
+        list_of_weak_references = '      list of weak references to the object (if defined)'  # fmt: skip
 
     # with :members:
     app.config.autodoc_default_options = {'members': 'val1,val2'}
