@@ -1,16 +1,23 @@
 """Test the autodoc extension."""
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 import pytest
 
 from tests.test_extensions.autodoc_util import do_autodoc
 
+if TYPE_CHECKING:
+    from sphinx.testing.util import SphinxTestApp
+
 
 @pytest.mark.sphinx(
     'html',
     testroot='ext-autodoc',
     confoverrides={'autodoc_preserve_defaults': True},
 )
-def test_preserve_defaults(app):
+def test_preserve_defaults(app: SphinxTestApp) -> None:
     color = '0xFFFFFF'
 
     options = {'members': None}
@@ -100,7 +107,7 @@ def test_preserve_defaults(app):
     testroot='ext-autodoc',
     confoverrides={'autodoc_preserve_defaults': True},
 )
-def test_preserve_defaults_special_constructs(app):
+def test_preserve_defaults_special_constructs(app: SphinxTestApp) -> None:
     options = {'members': None}
     actual = do_autodoc(
         app, 'module', 'target.preserve_defaults_special_constructs', options
