@@ -1,9 +1,15 @@
 """Test sphinx.ext.imgconverter extension."""
 
+from __future__ import annotations
+
 import subprocess
+from typing import TYPE_CHECKING
 
 import pytest
 
+if TYPE_CHECKING:
+    from sphinx.testing.util import SphinxTestApp
+
 
 @pytest.fixture
 def _if_converter_found(app):
@@ -25,7 +31,7 @@ def _if_converter_found(app):
 
 @pytest.mark.usefixtures('_if_converter_found')
 @pytest.mark.sphinx('latex', testroot='ext-imgconverter')
-def test_ext_imgconverter(app):
+def test_ext_imgconverter(app: SphinxTestApp) -> None:
     app.build(force_all=True)
 
     content = (app.outdir / 'projectnamenotset.tex').read_text(encoding='utf8')
