@@ -1,9 +1,12 @@
 """Test sphinx.ext.inheritance_diagram extension."""
 
-import os
+from __future__ import annotations
+
 import re
 import sys
 import zlib
+from pathlib import Path
+from typing import TYPE_CHECKING
 
 import pytest
 
@@ -12,12 +15,15 @@ from sphinx.ext.inheritance_diagram import (
     InheritanceException,
     import_classes,
 )
-from sphinx.ext.intersphinx import load_mappings, validate_intersphinx_mapping
+from sphinx.ext.intersphinx._load import load_mappings, validate_intersphinx_mapping
+
+if TYPE_CHECKING:
+    from sphinx.testing.util import SphinxTestApp
 
 
 @pytest.mark.sphinx('html', testroot='inheritance')
 @pytest.mark.usefixtures('if_graphviz_found')
-def test_inheritance_diagram(app):
+def test_inheritance_diagram(app: SphinxTestApp) -> None:
     # monkey-patch InheritaceDiagram.run() so we can get access to its
     # results.
     orig_run = InheritanceDiagram.run
@@ -26,16 +32,16 @@ def test_inheritance_diagram(app):
     def new_run(self):
         result = orig_run(self)
         node = result[0]
-        source = os.path.basename(node.document.current_source).replace('.rst', '')
+        source = Path(node.document.current_source).stem
         graphs[source] = node['graph']
         return result
 
-    InheritanceDiagram.run = new_run
+    InheritanceDiagram.run = new_run  # type: ignore[method-assign]
 
     try:
         app.build(force_all=True)
     finally:
-        InheritanceDiagram.run = orig_run
+        InheritanceDiagram.run = orig_run  # type: ignore[method-assign]
 
     assert app.statuscode == 0
 
@@ -48,25 +54,25 @@ def test_inheritance_diagram(app):
     # basic inheritance diagram showing all classes
     for cls in graphs['basic_diagram'].class_info:
         # use in b/c traversing order is different sometimes
-        assert cls in [
-            ('dummy.test.A', 'dummy.test.A', [], None),
-            ('dummy.test.F', 'dummy.test.F', ['dummy.test.C'], None),
-            ('dummy.test.C', 'dummy.test.C', ['dummy.test.A'], None),
-            ('dummy.test.E', 'dummy.test.E', ['dummy.test.B'], None),
-            ('dummy.test.D', 'dummy.test.D', ['dummy.test.B', 'dummy.test.C'], None),
-            ('dummy.test.B', 'dummy.test.B', ['dummy.test.A'], None),
-        ]
+        assert cls in {
+            ('dummy.test.A', 'dummy.test.A', (), None),
+            ('dummy.test.F', 'dummy.test.F', ('dummy.test.C',), None),
+            ('dummy.test.C', 'dummy.test.C', ('dummy.test.A',), None),
+            ('dummy.test.E', 'dummy.test.E', ('dummy.test.B',), None),
+            ('dummy.test.D', 'dummy.test.D', ('dummy.test.B', 'dummy.test.C'), None),
+            ('dummy.test.B', 'dummy.test.B', ('dummy.test.A',), None),
+        }
 
     # inheritance diagram using :parts: 1 option
     for cls in graphs['diagram_w_parts'].class_info:
-        assert cls in [
-            ('A', 'dummy.test.A', [], None),
-            ('F', 'dummy.test.F', ['C'], None),
-            ('C', 'dummy.test.C', ['A'], None),
-            ('E', 'dummy.test.E', ['B'], None),
-            ('D', 'dummy.test.D', ['B', 'C'], None),
-            ('B', 'dummy.test.B', ['A'], None),
-        ]
+        assert cls in {
+            ('A', 'dummy.test.A', (), None),
+            ('F', 'dummy.test.F', ('C',), None),
+            ('C', 'dummy.test.C', ('A',), None),
+            ('E', 'dummy.test.E', ('B',), None),
+            ('D', 'dummy.test.D', ('B', 'C'), None),
+            ('B', 'dummy.test.B', ('A',), None),
+        }
 
     # inheritance diagram with 1 top class
     # :top-classes: dummy.test.B
@@ -78,14 +84,14 @@ def test_inheritance_diagram(app):
     #   E   D   F
     #
     for cls in graphs['diagram_w_1_top_class'].class_info:
-        assert cls in [
-            ('dummy.test.A', 'dummy.test.A', [], None),
-            ('dummy.test.F', 'dummy.test.F', ['dummy.test.C'], None),
-            ('dummy.test.C', 'dummy.test.C', ['dummy.test.A'], None),
-            ('dummy.test.E', 'dummy.test.E', ['dummy.test.B'], None),
-            ('dummy.test.D', 'dummy.test.D', ['dummy.test.B', 'dummy.test.C'], None),
-            ('dummy.test.B', 'dummy.test.B', [], None),
-        ]
+        assert cls in {
+            ('dummy.test.A', 'dummy.test.A', (), None),
+            ('dummy.test.F', 'dummy.test.F', ('dummy.test.C',), None),
+            ('dummy.test.C', 'dummy.test.C', ('dummy.test.A',), None),
+            ('dummy.test.E', 'dummy.test.E', ('dummy.test.B',), None),
+            ('dummy.test.D', 'dummy.test.D', ('dummy.test.B', 'dummy.test.C'), None),
+            ('dummy.test.B', 'dummy.test.B', (), None),
+        }
 
     # inheritance diagram with 2 top classes
     # :top-classes: dummy.test.B, dummy.test.C
@@ -97,13 +103,13 @@ def test_inheritance_diagram(app):
     #   E   D   F
     #
     for cls in graphs['diagram_w_2_top_classes'].class_info:
-        assert cls in [
-            ('dummy.test.F', 'dummy.test.F', ['dummy.test.C'], None),
-            ('dummy.test.C', 'dummy.test.C', [], None),
-            ('dummy.test.E', 'dummy.test.E', ['dummy.test.B'], None),
-            ('dummy.test.D', 'dummy.test.D', ['dummy.test.B', 'dummy.test.C'], None),
-            ('dummy.test.B', 'dummy.test.B', [], None),
-        ]
+        assert cls in {
+            ('dummy.test.F', 'dummy.test.F', ('dummy.test.C',), None),
+            ('dummy.test.C', 'dummy.test.C', (), None),
+            ('dummy.test.E', 'dummy.test.E', ('dummy.test.B',), None),
+            ('dummy.test.D', 'dummy.test.D', ('dummy.test.B', 'dummy.test.C'), None),
+            ('dummy.test.B', 'dummy.test.B', (), None),
+        }
 
     # inheritance diagram with 2 top classes and specifying the entire module
     # rendering should be
@@ -119,27 +125,27 @@ def test_inheritance_diagram(app):
     # If you'd like to not show class A in the graph don't specify the entire module.
     # this is a known issue.
     for cls in graphs['diagram_module_w_2_top_classes'].class_info:
-        assert cls in [
-            ('dummy.test.F', 'dummy.test.F', ['dummy.test.C'], None),
-            ('dummy.test.C', 'dummy.test.C', [], None),
-            ('dummy.test.E', 'dummy.test.E', ['dummy.test.B'], None),
-            ('dummy.test.D', 'dummy.test.D', ['dummy.test.B', 'dummy.test.C'], None),
-            ('dummy.test.B', 'dummy.test.B', [], None),
-            ('dummy.test.A', 'dummy.test.A', [], None),
-        ]
+        assert cls in {
+            ('dummy.test.F', 'dummy.test.F', ('dummy.test.C',), None),
+            ('dummy.test.C', 'dummy.test.C', (), None),
+            ('dummy.test.E', 'dummy.test.E', ('dummy.test.B',), None),
+            ('dummy.test.D', 'dummy.test.D', ('dummy.test.B', 'dummy.test.C'), None),
+            ('dummy.test.B', 'dummy.test.B', (), None),
+            ('dummy.test.A', 'dummy.test.A', (), None),
+        }
 
     # inheritance diagram involving a base class nested within another class
     for cls in graphs['diagram_w_nested_classes'].class_info:
-        assert cls in [
-            ('dummy.test_nested.A', 'dummy.test_nested.A', [], None),
+        assert cls in {
+            ('dummy.test_nested.A', 'dummy.test_nested.A', (), None),
             (
                 'dummy.test_nested.C',
                 'dummy.test_nested.C',
-                ['dummy.test_nested.A.B'],
+                ('dummy.test_nested.A.B',),
                 None,
             ),
-            ('dummy.test_nested.A.B', 'dummy.test_nested.A.B', [], None),
-        ]
+            ('dummy.test_nested.A.B', 'dummy.test_nested.A.B', (), None),
+        }
 
 
 # An external inventory to test intersphinx links in inheritance diagrams
@@ -264,7 +270,7 @@ def test_inheritance_diagram_svg_html(tmp_path, app):
 
 @pytest.mark.sphinx('latex', testroot='ext-inheritance_diagram')
 @pytest.mark.usefixtures('if_graphviz_found')
-def test_inheritance_diagram_latex(app):
+def test_inheritance_diagram_latex(app: SphinxTestApp) -> None:
     app.build(force_all=True)
 
     content = (app.outdir / 'projectnamenotset.tex').read_text(encoding='utf8')
@@ -293,17 +299,17 @@ def test_inheritance_diagram_latex_alias(app):
     assert (
         'test.DocSubDir2',
         'test.DocSubDir2',
-        ['test.DocSubDir1'],
+        ('test.DocSubDir1',),
         None,
     ) in aliased_graph
     assert (
         'test.DocSubDir1',
         'test.DocSubDir1',
-        ['test.DocHere'],
+        ('test.DocHere',),
         None,
     ) in aliased_graph
-    assert ('test.DocHere', 'test.DocHere', ['alias.Foo'], None) in aliased_graph
-    assert ('alias.Foo', 'alias.Foo', [], None) in aliased_graph
+    assert ('test.DocHere', 'test.DocHere', ('alias.Foo',), None) in aliased_graph
+    assert ('alias.Foo', 'alias.Foo', (), None) in aliased_graph
 
     content = (app.outdir / 'index.html').read_text(encoding='utf8')
 
@@ -325,7 +331,7 @@ def test_import_classes(rootdir):
     saved_path = sys.path.copy()
     sys.path.insert(0, str(rootdir / 'test-ext-inheritance_diagram'))
     try:
-        from example.sphinx import DummyClass
+        from example.sphinx import DummyClass  # type: ignore[import-not-found]
 
         # got exception for unknown class or module
         with pytest.raises(InheritanceException):
@@ -334,7 +340,8 @@ def test_import_classes(rootdir):
             import_classes('unknown.Unknown', None)
 
         # got exception InheritanceException for wrong class or module
-        # not AttributeError (refs: #4019)
+        # not AttributeError
+        # See: https://github.com/sphinx-doc/sphinx/issues/4019
         with pytest.raises(InheritanceException):
             import_classes('unknown', '.')
         with pytest.raises(InheritanceException):
@@ -369,7 +376,8 @@ def test_import_classes(rootdir):
         with pytest.raises(InheritanceException):
             import_classes('encode_uri', 'sphinx.util')
 
-        # import submodule on current module (refs: #3164)
+        # import submodule on current module
+        # See: https://github.com/sphinx-doc/sphinx/issues/3164
         classes = import_classes('sphinx', 'example')
         assert classes == [DummyClass]
     finally:
