@@ -45,7 +45,7 @@ if TYPE_CHECKING:
     from sphinx.util.typing import Inventory
 
 
-class FakeList(list[str]):
+class FakeList(list[str]):  # NoQA: FURB189
     def __iter__(self) -> NoReturn:
         raise NotImplementedError
 
