@@ -1,9 +1,15 @@
 """Test sphinx.ext.todo extension."""
 
+from __future__ import annotations
+
 import re
+from typing import TYPE_CHECKING
 
 import pytest
 
+if TYPE_CHECKING:
+    from sphinx.testing.util import SphinxTestApp
+
 
 @pytest.mark.sphinx(
     'html',
@@ -11,7 +17,7 @@ import pytest
     freshenv=True,
     confoverrides={'todo_include_todos': True, 'todo_emit_warnings': True},
 )
-def test_todo(app):
+def test_todo(app: SphinxTestApp) -> None:
     todos = []
 
     def on_todo_defined(app, node):
@@ -53,7 +59,7 @@ def test_todo(app):
     freshenv=True,
     confoverrides={'todo_include_todos': False, 'todo_emit_warnings': True},
 )
-def test_todo_not_included(app):
+def test_todo_not_included(app: SphinxTestApp) -> None:
     todos = []
 
     def on_todo_defined(app, node):
@@ -91,11 +97,10 @@ def test_todo_not_included(app):
     freshenv=True,
     confoverrides={'todo_include_todos': True},
 )
-def test_todo_valid_link(app):
-    """
-    Test that the inserted "original entry" links for todo items have a target
-    that exists in the LaTeX output. The target was previously incorrectly
-    omitted (GitHub issue #1020).
+def test_todo_valid_link(app: SphinxTestApp) -> None:
+    """Test that the inserted "original entry" links for todo items have a target
+    that exists in the LaTeX output. The target was previously incorrectly omitted.
+    https://github.com/sphinx-doc/sphinx/issues/1020
     """
     # Ensure the LaTeX output is built.
     app.build(force_all=True)
