@@ -1,13 +1,20 @@
 """Test sphinx.extension module."""
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 import pytest
 
 from sphinx.errors import VersionRequirementError
 from sphinx.extension import Extension, verify_needs_extensions
 
+if TYPE_CHECKING:
+    from sphinx.testing.util import SphinxTestApp
+
 
 @pytest.mark.sphinx('html', testroot='root')
-def test_needs_extensions(app):
+def test_needs_extensions(app: SphinxTestApp) -> None:
     # empty needs_extensions
     assert app.config.needs_extensions == {}
     verify_needs_extensions(app, app.config)
