@@ -1,16 +1,23 @@
 """Test smart quotes."""
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 import pytest
 
 from sphinx.testing.util import etree_parse
 
+if TYPE_CHECKING:
+    from sphinx.testing.util import SphinxTestApp
+
 
 @pytest.mark.sphinx(
     'html',
     testroot='smartquotes',
     freshenv=True,
 )
-def test_basic(app):
+def test_basic(app: SphinxTestApp) -> None:
     app.build()
 
     content = (app.outdir / 'index.html').read_text(encoding='utf8')
@@ -22,7 +29,7 @@ def test_basic(app):
     testroot='smartquotes',
     freshenv=True,
 )
-def test_literals(app):
+def test_literals(app: SphinxTestApp) -> None:
     app.build()
 
     etree = etree_parse(app.outdir / 'literals.html')
@@ -42,7 +49,7 @@ def test_literals(app):
     testroot='smartquotes',
     freshenv=True,
 )
-def test_text_builder(app):
+def test_text_builder(app: SphinxTestApp) -> None:
     app.build()
 
     content = (app.outdir / 'index.txt').read_text(encoding='utf8')
@@ -54,7 +61,7 @@ def test_text_builder(app):
     testroot='smartquotes',
     freshenv=True,
 )
-def test_man_builder(app):
+def test_man_builder(app: SphinxTestApp) -> None:
     app.build()
 
     content = (app.outdir / 'projectnamenotset.1').read_text(encoding='utf8')
@@ -66,7 +73,7 @@ def test_man_builder(app):
     testroot='smartquotes',
     freshenv=True,
 )
-def test_latex_builder(app):
+def test_latex_builder(app: SphinxTestApp) -> None:
     app.build()
 
     content = (app.outdir / 'projectnamenotset.tex').read_text(encoding='utf8')
@@ -79,7 +86,7 @@ def test_latex_builder(app):
     freshenv=True,
     confoverrides={'language': 'ja'},
 )
-def test_ja_html_builder(app):
+def test_ja_html_builder(app: SphinxTestApp) -> None:
     app.build()
 
     content = (app.outdir / 'index.html').read_text(encoding='utf8')
@@ -92,7 +99,7 @@ def test_ja_html_builder(app):
     freshenv=True,
     confoverrides={'language': 'zh_CN'},
 )
-def test_zh_cn_html_builder(app):
+def test_zh_cn_html_builder(app: SphinxTestApp) -> None:
     app.build()
 
     content = (app.outdir / 'index.html').read_text(encoding='utf8')
@@ -105,7 +112,7 @@ def test_zh_cn_html_builder(app):
     freshenv=True,
     confoverrides={'language': 'zh_TW'},
 )
-def test_zh_tw_html_builder(app):
+def test_zh_tw_html_builder(app: SphinxTestApp) -> None:
     app.build()
 
     content = (app.outdir / 'index.html').read_text(encoding='utf8')
@@ -118,7 +125,7 @@ def test_zh_tw_html_builder(app):
     freshenv=True,
     confoverrides={'smartquotes': False},
 )
-def test_smartquotes_disabled(app):
+def test_smartquotes_disabled(app: SphinxTestApp) -> None:
     app.build()
 
     content = (app.outdir / 'index.html').read_text(encoding='utf8')
@@ -131,7 +138,7 @@ def test_smartquotes_disabled(app):
     freshenv=True,
     confoverrides={'smartquotes_action': 'q'},
 )
-def test_smartquotes_action(app):
+def test_smartquotes_action(app: SphinxTestApp) -> None:
     app.build()
 
     content = (app.outdir / 'index.html').read_text(encoding='utf8')
@@ -144,7 +151,7 @@ def test_smartquotes_action(app):
     freshenv=True,
     confoverrides={'language': 'ja', 'smartquotes_excludes': {}},
 )
-def test_smartquotes_excludes_language(app):
+def test_smartquotes_excludes_language(app: SphinxTestApp) -> None:
     app.build()
 
     content = (app.outdir / 'index.html').read_text(encoding='utf8')
@@ -157,7 +164,7 @@ def test_smartquotes_excludes_language(app):
     freshenv=True,
     confoverrides={'smartquotes_excludes': {}},
 )
-def test_smartquotes_excludes_builders(app):
+def test_smartquotes_excludes_builders(app: SphinxTestApp) -> None:
     app.build()
 
     content = (app.outdir / 'projectnamenotset.1').read_text(encoding='utf8')
