@@ -1,14 +1,17 @@
 """Test the Theme class."""
 
-import os
+from __future__ import annotations
+
 import shutil
 from pathlib import Path
+from typing import TYPE_CHECKING
 from xml.etree.ElementTree import ParseError
 
 import pytest
 from defusedxml.ElementTree import parse as xml_parse
 
 import sphinx.builders.html
+from sphinx.builders.html import StandaloneHTMLBuilder
 from sphinx.errors import ThemeError
 from sphinx.theming import (
     _ConfigFile,
@@ -19,6 +22,9 @@ from sphinx.theming import (
     _load_theme_toml,
 )
 
+if TYPE_CHECKING:
+    from sphinx.testing.util import SphinxTestApp
+
 HERE = Path(__file__).resolve().parent
 
 
@@ -27,7 +33,8 @@ HERE = Path(__file__).resolve().parent
     testroot='theming',
     confoverrides={'html_theme': 'ziptheme', 'html_theme_options.testopt': 'foo'},
 )
-def test_theme_api(app):
+def test_theme_api(app: SphinxTestApp) -> None:
+    assert isinstance(app.builder, StandaloneHTMLBuilder)  # type-checking
     themes = [
         'basic',
         'default',
@@ -52,11 +59,11 @@ def test_theme_api(app):
 
     # test Theme class API
     assert set(app.registry.html_themes.keys()) == set(themes)
-    assert app.registry.html_themes['test-theme'] == str(
+    assert app.registry.html_themes['test-theme'] == (
         app.srcdir / 'test_theme' / 'test-theme'
     )
-    assert app.registry.html_themes['ziptheme'] == str(app.srcdir / 'ziptheme.zip')
-    assert app.registry.html_themes['staticfiles'] == str(
+    assert app.registry.html_themes['ziptheme'] == (app.srcdir / 'ziptheme.zip')
+    assert app.registry.html_themes['staticfiles'] == (
         app.srcdir / 'test_theme' / 'staticfiles'
     )
 
@@ -88,18 +95,19 @@ def test_theme_api(app):
 
     # cleanup temp directories
     theme._cleanup()
-    assert not any(map(os.path.exists, theme._tmp_dirs))
+    assert not any(p.exists() for p in theme._tmp_dirs)
 
 
 def test_nonexistent_theme_settings(tmp_path):
     # Check that error occurs with a non-existent theme.toml or theme.conf
-    # (https://github.com/sphinx-doc/sphinx/issues/11668)
+    # https://github.com/sphinx-doc/sphinx/issues/11668
     with pytest.raises(ThemeError):
-        _load_theme('', str(tmp_path))
+        _load_theme('', tmp_path)
 
 
 @pytest.mark.sphinx('html', testroot='double-inheriting-theme')
-def test_double_inheriting_theme(app):
+def test_double_inheriting_theme(app: SphinxTestApp) -> None:
+    assert isinstance(app.builder, StandaloneHTMLBuilder)  # type-checking
     assert app.builder.theme.name == 'base_theme2'
     app.build()  # => not raises TemplateNotFound
 
@@ -109,7 +117,8 @@ def test_double_inheriting_theme(app):
     testroot='theming',
     confoverrides={'html_theme': 'child'},
 )
-def test_nested_zipped_theme(app):
+def test_nested_zipped_theme(app: SphinxTestApp) -> None:
+    assert isinstance(app.builder, StandaloneHTMLBuilder)  # type-checking
     assert app.builder.theme.name == 'child'
     app.build()  # => not raises TemplateNotFound
 
@@ -119,7 +128,7 @@ def test_nested_zipped_theme(app):
     testroot='theming',
     confoverrides={'html_theme': 'staticfiles'},
 )
-def test_staticfiles(app):
+def test_staticfiles(app: SphinxTestApp) -> None:
     app.build()
     assert (app.outdir / '_static' / 'legacytmpl.html').exists()
     assert (app.outdir / '_static' / 'legacytmpl.html').read_text(encoding='utf8') == (
@@ -173,7 +182,7 @@ def test_dark_style(app, monkeypatch):
 
 
 @pytest.mark.sphinx('html', testroot='theming')
-def test_theme_sidebars(app):
+def test_theme_sidebars(app: SphinxTestApp) -> None:
     app.build()
 
     # test-theme specifies globaltoc and searchbox as default sidebars
@@ -222,9 +231,9 @@ def test_theme_builds(make_app, rootdir, sphinx_test_tempdir, theme_name):
             pytest.fail(f'Failed to parse {html_file.relative_to(app.outdir)}: {exc}')
 
 
-def test_config_file_toml():
+def test_config_file_toml() -> None:
     config_path = HERE / 'theme.toml'
-    cfg = _load_theme_toml(str(config_path))
+    cfg = _load_theme_toml(config_path)
     config = _convert_theme_toml(cfg)
 
     assert config == _ConfigFile(
@@ -236,9 +245,9 @@ def test_config_file_toml():
     )
 
 
-def test_config_file_conf():
+def test_config_file_conf() -> None:
     config_path = HERE / 'theme.conf'
-    cfg = _load_theme_conf(str(config_path))
+    cfg = _load_theme_conf(config_path)
     config = _convert_theme_conf(cfg)
 
     assert config == _ConfigFile(
