@@ -61,14 +61,14 @@ def make_directive_and_state(
     return state, directive
 
 
-def test_sphinx_directive_env():
+def test_sphinx_directive_env() -> None:
     state, directive = make_directive_and_state(env=SimpleNamespace())
 
     assert hasattr(directive, 'env')
     assert directive.env is state.document.settings.env
 
 
-def test_sphinx_directive_config():
+def test_sphinx_directive_config() -> None:
     env = SimpleNamespace(config=object())
     state, directive = make_directive_and_state(env=env)
 
@@ -77,7 +77,7 @@ def test_sphinx_directive_config():
     assert directive.config is state.document.settings.env.config
 
 
-def test_sphinx_directive_get_source_info():
+def test_sphinx_directive_get_source_info() -> None:
     env = SimpleNamespace()
     input_lines = StringList(['spam'], source='<source>')
     directive = make_directive(env=env, input_lines=input_lines)
@@ -85,7 +85,7 @@ def test_sphinx_directive_get_source_info():
     assert directive.get_source_info() == ('<source>', 1)
 
 
-def test_sphinx_directive_set_source_info():
+def test_sphinx_directive_set_source_info() -> None:
     env = SimpleNamespace()
     input_lines = StringList(['spam'], source='<source>')
     directive = make_directive(env=env, input_lines=input_lines)
@@ -96,7 +96,7 @@ def test_sphinx_directive_set_source_info():
     assert node.line == 1
 
 
-def test_sphinx_directive_get_location():
+def test_sphinx_directive_get_location() -> None:
     env = SimpleNamespace()
     input_lines = StringList(['spam'], source='<source>')
     directive = make_directive(env=env, input_lines=input_lines)
@@ -104,7 +104,7 @@ def test_sphinx_directive_get_location():
     assert directive.get_location() == '<source>:1'
 
 
-def test_sphinx_directive_parse_content_to_nodes():
+def test_sphinx_directive_parse_content_to_nodes() -> None:
     directive = make_directive(env=SimpleNamespace())
     content = 'spam\n====\n\nEggs! *Lobster thermidor.*'
     directive.content = StringList(content.split('\n'), source='<source>')
@@ -120,7 +120,7 @@ def test_sphinx_directive_parse_content_to_nodes():
     assert node.children[1].astext() == 'Eggs! Lobster thermidor.'
 
 
-def test_sphinx_directive_parse_text_to_nodes():
+def test_sphinx_directive_parse_text_to_nodes() -> None:
     directive = make_directive(env=SimpleNamespace())
     content = 'spam\n====\n\nEggs! *Lobster thermidor.*'
 
@@ -135,7 +135,7 @@ def test_sphinx_directive_parse_text_to_nodes():
     assert node.children[1].astext() == 'Eggs! Lobster thermidor.'
 
 
-def test_sphinx_directive_parse_inline():
+def test_sphinx_directive_parse_inline() -> None:
     directive = make_directive(env=SimpleNamespace())
     content = 'Eggs! *Lobster thermidor.*'
 
