@@ -1,12 +1,38 @@
 """Tests util.typing functions."""
 
+from __future__ import annotations
+
+import ctypes
 import dataclasses
 import sys
 import typing as t
+import zipfile
 from collections import abc
 from contextvars import Context, ContextVar, Token
 from enum import Enum
+from io import (
+    BufferedRandom,
+    BufferedReader,
+    BufferedRWPair,
+    BufferedWriter,
+    BytesIO,
+    FileIO,
+    StringIO,
+    TextIOWrapper,
+)
+from json import JSONDecoder, JSONEncoder
+from lzma import LZMACompressor, LZMADecompressor
+from multiprocessing import Process
 from numbers import Integral
+from pathlib import (
+    Path,
+    PosixPath,
+    PurePath,
+    PurePosixPath,
+    PureWindowsPath,
+    WindowsPath,
+)
+from pickle import Pickler, Unpickler
 from struct import Struct
 from types import (
     AsyncGeneratorType,
@@ -16,6 +42,7 @@ from types import (
     ClassMethodDescriptorType,
     CodeType,
     CoroutineType,
+    EllipsisType,
     FrameType,
     FunctionType,
     GeneratorType,
@@ -27,6 +54,8 @@ from types import (
     MethodType,
     MethodWrapperType,
     ModuleType,
+    NoneType,
+    NotImplementedType,
     TracebackType,
     WrapperDescriptorType,
 )
@@ -44,8 +73,9 @@ from typing import (
     TypeVar,
     Union,
 )
+from weakref import WeakSet
 
-from sphinx.ext.autodoc import mock
+from sphinx.ext.autodoc.mock import mock
 from sphinx.util.typing import _INVALID_BUILTIN_CLASSES, restify, stringify_annotation
 
 
@@ -78,7 +108,7 @@ class Gt:
     gt: float
 
 
-def test_restify():
+def test_restify() -> None:
     assert restify(int) == ':py:class:`int`'
     assert restify(int, 'smart') == ':py:class:`int`'
 
@@ -97,6 +127,9 @@ def test_restify():
     assert restify(TracebackType) == ':py:class:`types.TracebackType`'
     assert restify(TracebackType, 'smart') == ':py:class:`~types.TracebackType`'
 
+    assert restify(Path) == ':py:class:`pathlib.Path`'
+    assert restify(Path, 'smart') == ':py:class:`~pathlib.Path`'
+
     assert restify(Any) == ':py:obj:`~typing.Any`'
     assert restify(Any, 'smart') == ':py:obj:`~typing.Any`'
 
@@ -104,15 +137,42 @@ def test_restify():
     assert restify('str', 'smart') == 'str'
 
 
-def test_is_invalid_builtin_class():
+def test_is_invalid_builtin_class() -> None:
     # if these tests start failing, it means that the __module__
     # of one of these classes has changed, and _INVALID_BUILTIN_CLASSES
     # in sphinx.util.typing needs to be updated.
-    assert _INVALID_BUILTIN_CLASSES.keys() == {
+    invalid_types = (
+        # contextvars
         Context,
         ContextVar,
         Token,
+        # ctypes
+        ctypes.Array,
+        ctypes.Structure,
+        ctypes.Union,
+        # io
+        FileIO,
+        BytesIO,
+        StringIO,
+        BufferedReader,
+        BufferedWriter,
+        BufferedRWPair,
+        BufferedRandom,
+        TextIOWrapper,
+        # json
+        JSONDecoder,
+        JSONEncoder,
+        # lzma
+        LZMACompressor,
+        LZMADecompressor,
+        # multiprocessing
+        Process,
+        # pickle
+        Pickler,
+        Unpickler,
+        # struct
         Struct,
+        # types
         AsyncGeneratorType,
         BuiltinFunctionType,
         BuiltinMethodType,
@@ -120,6 +180,7 @@ def test_is_invalid_builtin_class():
         ClassMethodDescriptorType,
         CodeType,
         CoroutineType,
+        EllipsisType,
         FrameType,
         FunctionType,
         GeneratorType,
@@ -131,30 +192,46 @@ def test_is_invalid_builtin_class():
         MethodType,
         MethodWrapperType,
         ModuleType,
+        NoneType,
+        NotImplementedType,
         TracebackType,
         WrapperDescriptorType,
-    }
-    assert Struct.__module__ == '_struct'
-    assert AsyncGeneratorType.__module__ == 'builtins'
-    assert BuiltinFunctionType.__module__ == 'builtins'
-    assert BuiltinMethodType.__module__ == 'builtins'
-    assert CellType.__module__ == 'builtins'
-    assert ClassMethodDescriptorType.__module__ == 'builtins'
-    assert CodeType.__module__ == 'builtins'
-    assert CoroutineType.__module__ == 'builtins'
-    assert FrameType.__module__ == 'builtins'
-    assert FunctionType.__module__ == 'builtins'
-    assert GeneratorType.__module__ == 'builtins'
-    assert GetSetDescriptorType.__module__ == 'builtins'
-    assert LambdaType.__module__ == 'builtins'
-    assert MappingProxyType.__module__ == 'builtins'
-    assert MemberDescriptorType.__module__ == 'builtins'
-    assert MethodDescriptorType.__module__ == 'builtins'
-    assert MethodType.__module__ == 'builtins'
-    assert MethodWrapperType.__module__ == 'builtins'
-    assert ModuleType.__module__ == 'builtins'
-    assert TracebackType.__module__ == 'builtins'
-    assert WrapperDescriptorType.__module__ == 'builtins'
+        # weakref
+        WeakSet,
+    )
+    if sys.version_info[:2] >= (3, 12):
+        invalid_types += (
+            # zipfile
+            zipfile.Path,
+            zipfile.CompleteDirs,
+        )
+    if sys.version_info[:2] >= (3, 13):
+        invalid_types += (
+            # pathlib
+            Path,
+            PosixPath,
+            PurePath,
+            PurePosixPath,
+            PureWindowsPath,
+            WindowsPath,
+        )
+
+    invalid_names = {(cls.__module__, cls.__qualname__) for cls in invalid_types}
+    if sys.version_info[:2] < (3, 13):
+        invalid_names |= {
+            ('pathlib._local', 'Path'),
+            ('pathlib._local', 'PosixPath'),
+            ('pathlib._local', 'PurePath'),
+            ('pathlib._local', 'PurePosixPath'),
+            ('pathlib._local', 'PureWindowsPath'),
+            ('pathlib._local', 'WindowsPath'),
+        }
+    if sys.version_info[:2] < (3, 12):
+        invalid_names |= {
+            ('zipfile._path', 'Path'),
+            ('zipfile._path', 'CompleteDirs'),
+        }
+    assert _INVALID_BUILTIN_CLASSES.keys() == invalid_names
 
 
 def test_restify_type_hints_containers():
@@ -173,10 +250,7 @@ def test_restify_type_hints_containers():
     ann_rst = restify(Tuple[str, ...])
     assert ann_rst == ':py:class:`~typing.Tuple`\\ [:py:class:`str`, ...]'
 
-    if sys.version_info[:2] <= (3, 10):
-        assert restify(Tuple[()]) == ':py:class:`~typing.Tuple`\\ [()]'
-    else:
-        assert restify(Tuple[()]) == ':py:class:`~typing.Tuple`'
+    assert restify(Tuple[()]) == ':py:class:`~typing.Tuple`'
 
     assert restify(List[Dict[str, Tuple]]) == (
         ':py:class:`~typing.List`\\ '
@@ -206,7 +280,7 @@ def test_restify_type_hints_containers():
     )
 
 
-def test_restify_Annotated():
+def test_restify_Annotated() -> None:
     ann_rst = restify(Annotated[str, 'foo', 'bar'])
     assert ann_rst == (
         ":py:class:`~typing.Annotated`\\ [:py:class:`str`, 'foo', 'bar']"
@@ -225,7 +299,7 @@ def test_restify_Annotated():
     )
 
 
-def test_restify_type_hints_Callable():
+def test_restify_type_hints_Callable() -> None:
     assert restify(t.Callable) == ':py:class:`~typing.Callable`'
     assert restify(t.Callable[[str], int]) == (
         ':py:class:`~typing.Callable`\\ [[:py:class:`str`], :py:class:`int`]'
@@ -242,7 +316,7 @@ def test_restify_type_hints_Callable():
     )
 
 
-def test_restify_type_hints_Union():
+def test_restify_type_hints_Union() -> None:
     assert restify(Union[int]) == ':py:class:`int`'
     assert restify(Union[int, str]) == ':py:class:`int` | :py:class:`str`'
     assert restify(Optional[int]) == ':py:class:`int` | :py:obj:`None`'
@@ -325,7 +399,7 @@ def test_restify_type_hints_typevars():
     assert ann_rst == ':py:class:`~tests.test_util.test_util_typing.MyInt`'
 
 
-def test_restify_type_hints_custom_class():
+def test_restify_type_hints_custom_class() -> None:
     assert restify(MyClass1) == ':py:class:`tests.test_util.test_util_typing.MyClass1`'
     ann_rst = restify(MyClass1, 'smart')
     assert ann_rst == ':py:class:`~tests.test_util.test_util_typing.MyClass1`'
@@ -336,7 +410,7 @@ def test_restify_type_hints_custom_class():
     assert ann_rst == ':py:class:`~tests.test_util.test_util_typing.<MyClass2>`'
 
 
-def test_restify_type_hints_alias():
+def test_restify_type_hints_alias() -> None:
     MyStr = str
     MyTypingTuple = Tuple[str, str]
     MyTuple = tuple[str, str]
@@ -353,13 +427,13 @@ def test_restify_type_ForwardRef():
         restify(list[ForwardRef('MyInt')]) == ':py:class:`list`\\ [:py:class:`MyInt`]'
     )
 
-    ann_rst = restify(Tuple[dict[ForwardRef('MyInt'), str], list[List[int]]])  # type: ignore[attr-defined]
+    ann_rst = restify(Tuple[dict[ForwardRef('MyInt'), str], list[List[int]]])
     assert ann_rst == (
         ':py:class:`~typing.Tuple`\\ [:py:class:`dict`\\ [:py:class:`MyInt`, :py:class:`str`], :py:class:`list`\\ [:py:class:`~typing.List`\\ [:py:class:`int`]]]'
     )
 
 
-def test_restify_type_Literal():
+def test_restify_type_Literal() -> None:
     ann_rst = restify(Literal[1, '2', '\r'])
     assert ann_rst == ":py:obj:`~typing.Literal`\\ [1, '2', '\\r']"
 
@@ -373,15 +447,15 @@ def test_restify_type_Literal():
     )
 
 
-def test_restify_pep_585():
-    assert restify(list[str]) == ':py:class:`list`\\ [:py:class:`str`]'  # type: ignore[attr-defined]
-    ann_rst = restify(dict[str, str])  # type: ignore[attr-defined]
+def test_restify_pep_585() -> None:
+    assert restify(list[str]) == ':py:class:`list`\\ [:py:class:`str`]'
+    ann_rst = restify(dict[str, str])
     assert ann_rst == ':py:class:`dict`\\ [:py:class:`str`, :py:class:`str`]'
     assert restify(tuple[str, ...]) == ':py:class:`tuple`\\ [:py:class:`str`, ...]'
     assert restify(tuple[str, str, str]) == (
         ':py:class:`tuple`\\ [:py:class:`str`, :py:class:`str`, :py:class:`str`]'
     )
-    ann_rst = restify(dict[str, tuple[int, ...]])  # type: ignore[attr-defined]
+    ann_rst = restify(dict[str, tuple[int, ...]])
     assert ann_rst == (
         ':py:class:`dict`\\ '
         '[:py:class:`str`, :py:class:`tuple`\\ '
@@ -405,7 +479,7 @@ def test_restify_pep_585():
     )
 
 
-def test_restify_Unpack():
+def test_restify_Unpack() -> None:
     from typing_extensions import Unpack as UnpackCompat
 
     class X(t.TypedDict):
@@ -423,30 +497,29 @@ def test_restify_Unpack():
         assert restify(UnpackCompat['X'], 'fully-qualified-except-typing') == expect
         assert restify(UnpackCompat['X'], 'smart') == expect
 
-    if sys.version_info[:2] >= (3, 11):
-        expect = r':py:obj:`~typing.Unpack`\ [:py:class:`X`]'
-        assert restify(t.Unpack['X'], 'fully-qualified-except-typing') == expect
-        assert restify(t.Unpack['X'], 'smart') == expect
+    expect = r':py:obj:`~typing.Unpack`\ [:py:class:`X`]'
+    assert restify(t.Unpack['X'], 'fully-qualified-except-typing') == expect
+    assert restify(t.Unpack['X'], 'smart') == expect
 
 
-def test_restify_type_union_operator():
-    assert restify(int | None) == ':py:class:`int` | :py:obj:`None`'  # type: ignore[attr-defined]
-    assert restify(None | int) == ':py:obj:`None` | :py:class:`int`'  # type: ignore[attr-defined]
-    assert restify(int | str) == ':py:class:`int` | :py:class:`str`'  # type: ignore[attr-defined]
-    ann_rst = restify(int | str | None)  # type: ignore[attr-defined]
+def test_restify_type_union_operator() -> None:
+    assert restify(int | None) == ':py:class:`int` | :py:obj:`None`'
+    assert restify(None | int) == ':py:obj:`None` | :py:class:`int`'
+    assert restify(int | str) == ':py:class:`int` | :py:class:`str`'
+    ann_rst = restify(int | str | None)
     assert ann_rst == ':py:class:`int` | :py:class:`str` | :py:obj:`None`'
 
 
-def test_restify_broken_type_hints():
+def test_restify_broken_type_hints() -> None:
     ann_rst = restify(BrokenType)
     assert ann_rst == ':py:class:`tests.test_util.test_util_typing.BrokenType`'
     ann_rst = restify(BrokenType, 'smart')
     assert ann_rst == ':py:class:`~tests.test_util.test_util_typing.BrokenType`'
 
 
-def test_restify_mock():
+def test_restify_mock() -> None:
     with mock(['unknown']):
-        import unknown
+        import unknown  # type: ignore[import-not-found]
 
         assert restify(unknown) == ':py:class:`unknown`'
         assert restify(unknown.secret.Class) == ':py:class:`unknown.secret.Class`'
@@ -467,7 +540,7 @@ def test_restify_type_hints_paramspec():
     assert restify(P.kwargs, 'smart') == 'P.kwargs'
 
 
-def test_stringify_annotation():
+def test_stringify_annotation() -> None:
     assert stringify_annotation(int, 'fully-qualified-except-typing') == 'int'
     assert stringify_annotation(int, 'smart') == 'int'
 
@@ -489,6 +562,10 @@ def test_stringify_annotation():
     assert ann_str == 'types.TracebackType'
     assert stringify_annotation(TracebackType, 'smart') == '~types.TracebackType'
 
+    ann_str = stringify_annotation(Path, 'fully-qualified-except-typing')
+    assert ann_str == 'pathlib.Path'
+    assert stringify_annotation(Path, 'smart') == '~pathlib.Path'
+
     assert stringify_annotation(Any, 'fully-qualified-except-typing') == 'Any'
     assert stringify_annotation(Any, 'fully-qualified') == 'typing.Any'
     assert stringify_annotation(Any, 'smart') == '~typing.Any'
@@ -534,17 +611,9 @@ def test_stringify_type_hints_containers():
     assert ann_str == 'typing.Tuple[str, ...]'
     assert stringify_annotation(Tuple[str, ...], 'smart') == '~typing.Tuple[str, ...]'
 
-    if sys.version_info[:2] <= (3, 10):
-        ann_str = stringify_annotation(Tuple[()], 'fully-qualified-except-typing')
-        assert ann_str == 'Tuple[()]'
-        assert stringify_annotation(Tuple[()], 'fully-qualified') == 'typing.Tuple[()]'
-        assert stringify_annotation(Tuple[()], 'smart') == '~typing.Tuple[()]'
-    else:
-        assert (
-            stringify_annotation(Tuple[()], 'fully-qualified-except-typing') == 'Tuple'
-        )
-        assert stringify_annotation(Tuple[()], 'fully-qualified') == 'typing.Tuple'
-        assert stringify_annotation(Tuple[()], 'smart') == '~typing.Tuple'
+    assert stringify_annotation(Tuple[()], 'fully-qualified-except-typing') == 'Tuple'
+    assert stringify_annotation(Tuple[()], 'fully-qualified') == 'typing.Tuple'
+    assert stringify_annotation(Tuple[()], 'smart') == '~typing.Tuple'
 
     ann_str = stringify_annotation(
         List[Dict[str, Tuple]], 'fully-qualified-except-typing'
@@ -657,7 +726,7 @@ def test_stringify_type_hints_pep_585():
     assert ann_str == 'tuple[~typing.List[dict[int, str]], str, ...]'
 
 
-def test_stringify_Annotated():
+def test_stringify_Annotated() -> None:
     ann_str = stringify_annotation(
         Annotated[str, 'foo', 'bar'], 'fully-qualified-except-typing'
     )
@@ -676,34 +745,17 @@ def test_stringify_Annotated():
     )
 
 
-def test_stringify_Unpack():
-    from typing_extensions import Unpack as UnpackCompat
-
+def test_stringify_Unpack() -> None:
     class X(t.TypedDict):
         x: int
         y: int
         label: str
 
-    if sys.version_info[:2] >= (3, 11):
-        # typing.Unpack is introduced in 3.11 but typing_extensions.Unpack only
-        # uses typing.Unpack in 3.12+, so the objects are not synchronised with
-        # each other, but we will assume that users use typing.Unpack.
-        import typing
-
-        UnpackCompat = typing.Unpack  # NoQA: F811
-        assert stringify_annotation(UnpackCompat['X']) == 'Unpack[X]'
-        assert stringify_annotation(UnpackCompat['X'], 'smart') == '~typing.Unpack[X]'
-    else:
-        assert stringify_annotation(UnpackCompat['X']) == 'typing_extensions.Unpack[X]'
-        ann_str = stringify_annotation(UnpackCompat['X'], 'smart')
-        assert ann_str == '~typing_extensions.Unpack[X]'
-
-    if sys.version_info[:2] >= (3, 11):
-        assert stringify_annotation(t.Unpack['X']) == 'Unpack[X]'
-        assert stringify_annotation(t.Unpack['X'], 'smart') == '~typing.Unpack[X]'
+    assert stringify_annotation(t.Unpack['X']) == 'Unpack[X]'
+    assert stringify_annotation(t.Unpack['X'], 'smart') == '~typing.Unpack[X]'
 
 
-def test_stringify_type_hints_string():
+def test_stringify_type_hints_string() -> None:
     assert stringify_annotation('int', 'fully-qualified-except-typing') == 'int'
     assert stringify_annotation('int', 'fully-qualified') == 'int'
     assert stringify_annotation('int', 'smart') == 'int'
@@ -737,7 +789,7 @@ def test_stringify_type_hints_string():
     assert stringify_annotation('unknown', 'smart') == 'unknown'
 
 
-def test_stringify_type_hints_Callable():
+def test_stringify_type_hints_Callable() -> None:
     ann_str = stringify_annotation(t.Callable, 'fully-qualified-except-typing')
     assert ann_str == 'Callable'
     assert stringify_annotation(t.Callable, 'fully-qualified') == 'typing.Callable'
@@ -786,7 +838,7 @@ def test_stringify_type_hints_Callable():
     assert ann_str == '~collections.abc.Callable[[...], int]'
 
 
-def test_stringify_type_hints_Union():
+def test_stringify_type_hints_Union() -> None:
     ann_str = stringify_annotation(Optional[int], 'fully-qualified-except-typing')
     assert ann_str == 'int | None'
     assert stringify_annotation(Optional[int], 'fully-qualified') == 'int | None'
@@ -866,7 +918,7 @@ def test_stringify_type_hints_typevars():
     assert ann_str == '~tests.test_util.test_util_typing.MyInt'
 
 
-def test_stringify_type_hints_custom_class():
+def test_stringify_type_hints_custom_class() -> None:
     ann_str = stringify_annotation(MyClass1, 'fully-qualified-except-typing')
     assert ann_str == 'tests.test_util.test_util_typing.MyClass1'
     ann_str = stringify_annotation(MyClass1, 'smart')
@@ -878,18 +930,18 @@ def test_stringify_type_hints_custom_class():
     assert ann_str == '~tests.test_util.test_util_typing.<MyClass2>'
 
 
-def test_stringify_type_hints_alias():
+def test_stringify_type_hints_alias() -> None:
     MyStr = str
     MyTuple = Tuple[str, str]
 
     assert stringify_annotation(MyStr, 'fully-qualified-except-typing') == 'str'
     assert stringify_annotation(MyStr, 'smart') == 'str'
 
-    assert stringify_annotation(MyTuple) == 'Tuple[str, str]'  # type: ignore[attr-defined]
-    assert stringify_annotation(MyTuple, 'smart') == '~typing.Tuple[str, str]'  # type: ignore[attr-defined]
+    assert stringify_annotation(MyTuple) == 'Tuple[str, str]'
+    assert stringify_annotation(MyTuple, 'smart') == '~typing.Tuple[str, str]'
 
 
-def test_stringify_type_Literal():
+def test_stringify_type_Literal() -> None:
     ann_str = stringify_annotation(
         Literal[1, '2', '\r'], 'fully-qualified-except-typing'
     )
@@ -907,37 +959,37 @@ def test_stringify_type_Literal():
     assert ann_str == '~typing.Literal[MyEnum.a]'
 
 
-def test_stringify_type_union_operator():
-    assert stringify_annotation(int | None) == 'int | None'  # type: ignore[attr-defined]
-    assert stringify_annotation(int | None, 'smart') == 'int | None'  # type: ignore[attr-defined]
+def test_stringify_type_union_operator() -> None:
+    assert stringify_annotation(int | None) == 'int | None'
+    assert stringify_annotation(int | None, 'smart') == 'int | None'
 
-    assert stringify_annotation(int | str) == 'int | str'  # type: ignore[attr-defined]
-    assert stringify_annotation(int | str, 'smart') == 'int | str'  # type: ignore[attr-defined]
+    assert stringify_annotation(int | str) == 'int | str'
+    assert stringify_annotation(int | str, 'smart') == 'int | str'
 
-    assert stringify_annotation(int | str | None) == 'int | str | None'  # type: ignore[attr-defined]
-    assert stringify_annotation(int | str | None, 'smart') == 'int | str | None'  # type: ignore[attr-defined]
+    assert stringify_annotation(int | str | None) == 'int | str | None'
+    assert stringify_annotation(int | str | None, 'smart') == 'int | str | None'
 
     ann_str = stringify_annotation(
         int | tuple[dict[str, int | None], list[int | str]] | None
     )
-    assert ann_str == 'int | tuple[dict[str, int | None], list[int | str]] | None'  # type: ignore[attr-defined]
+    assert ann_str == 'int | tuple[dict[str, int | None], list[int | str]] | None'
     ann_str = stringify_annotation(
         int | tuple[dict[str, int | None], list[int | str]] | None, 'smart'
     )
-    assert ann_str == 'int | tuple[dict[str, int | None], list[int | str]] | None'  # type: ignore[attr-defined]
+    assert ann_str == 'int | tuple[dict[str, int | None], list[int | str]] | None'
 
-    assert stringify_annotation(int | Struct) == 'int | struct.Struct'  # type: ignore[attr-defined]
-    assert stringify_annotation(int | Struct, 'smart') == 'int | ~struct.Struct'  # type: ignore[attr-defined]
+    assert stringify_annotation(int | Struct) == 'int | struct.Struct'
+    assert stringify_annotation(int | Struct, 'smart') == 'int | ~struct.Struct'
 
 
-def test_stringify_broken_type_hints():
+def test_stringify_broken_type_hints() -> None:
     ann_str = stringify_annotation(BrokenType, 'fully-qualified-except-typing')
     assert ann_str == 'tests.test_util.test_util_typing.BrokenType'
     ann_str = stringify_annotation(BrokenType, 'smart')
     assert ann_str == '~tests.test_util.test_util_typing.BrokenType'
 
 
-def test_stringify_mock():
+def test_stringify_mock() -> None:
     with mock(['unknown']):
         import unknown
 
@@ -961,16 +1013,16 @@ def test_stringify_type_ForwardRef():
     ann_str = stringify_annotation(
         Tuple[dict[ForwardRef('MyInt'), str], list[List[int]]]
     )
-    assert ann_str == 'Tuple[dict[MyInt, str], list[List[int]]]'  # type: ignore[attr-defined]
+    assert ann_str == 'Tuple[dict[MyInt, str], list[List[int]]]'
     ann_str = stringify_annotation(
         Tuple[dict[ForwardRef('MyInt'), str], list[List[int]]],
         'fully-qualified-except-typing',
     )
-    assert ann_str == 'Tuple[dict[MyInt, str], list[List[int]]]'  # type: ignore[attr-defined]
+    assert ann_str == 'Tuple[dict[MyInt, str], list[List[int]]]'
     ann_str = stringify_annotation(
         Tuple[dict[ForwardRef('MyInt'), str], list[List[int]]], 'smart'
     )
-    assert ann_str == '~typing.Tuple[dict[MyInt, str], list[~typing.List[int]]]'  # type: ignore[attr-defined]
+    assert ann_str == '~typing.Tuple[dict[MyInt, str], list[~typing.List[int]]]'
 
 
 def test_stringify_type_hints_paramspec():
