@@ -1,5 +1,7 @@
 """Test the versioning implementation."""
 
+from __future__ import annotations
+
 import pickle
 import shutil
 
@@ -8,12 +10,12 @@ import pytest
 from sphinx.testing.util import SphinxTestApp
 from sphinx.versioning import add_uids, get_ratio, merge_doctrees
 
-app = original = original_uids = None
+original = original_uids = None
 
 
 @pytest.fixture(scope='module', autouse=True)
 def _setup_module(rootdir, sphinx_test_tempdir):
-    global app, original, original_uids
+    global original, original_uids  # NoQA: PLW0603
     srcdir = sphinx_test_tempdir / 'test-versioning'
     if not srcdir.exists():
         shutil.copytree(rootdir / 'test-versioning', srcdir)
@@ -38,16 +40,16 @@ def is_paragraph(node):
     return node.__class__.__name__ == 'paragraph'
 
 
-def test_get_ratio():
+def test_get_ratio() -> None:
     assert get_ratio('', 'a')
     assert get_ratio('a', '')
 
 
-def test_add_uids():
+def test_add_uids() -> None:
     assert len(original_uids) == 3
 
 
-def test_picklablility():
+def test_pickleablility() -> None:
     # we have to modify the doctree so we can pickle it
     copy = original.copy()
     copy.reporter = None
@@ -59,7 +61,7 @@ def test_picklablility():
     assert all(getattr(n, 'uid', False) for n in loaded.findall(is_paragraph))
 
 
-def test_modified():
+def test_modified() -> None:
     modified = doctrees['modified']
     new_nodes = list(merge_doctrees(original, modified, is_paragraph))
     uids = [n.uid for n in modified.findall(is_paragraph)]
@@ -67,7 +69,7 @@ def test_modified():
     assert original_uids == uids
 
 
-def test_added():
+def test_added() -> None:
     added = doctrees['added']
     new_nodes = list(merge_doctrees(original, added, is_paragraph))
     uids = [n.uid for n in added.findall(is_paragraph)]
@@ -75,7 +77,7 @@ def test_added():
     assert original_uids == uids[:-1]
 
 
-def test_deleted():
+def test_deleted() -> None:
     deleted = doctrees['deleted']
     new_nodes = list(merge_doctrees(original, deleted, is_paragraph))
     uids = [n.uid for n in deleted.findall(is_paragraph)]
@@ -83,7 +85,7 @@ def test_deleted():
     assert original_uids[::2] == uids
 
 
-def test_deleted_end():
+def test_deleted_end() -> None:
     deleted_end = doctrees['deleted_end']
     new_nodes = list(merge_doctrees(original, deleted_end, is_paragraph))
     uids = [n.uid for n in deleted_end.findall(is_paragraph)]
@@ -91,7 +93,7 @@ def test_deleted_end():
     assert original_uids[:-1] == uids
 
 
-def test_insert():
+def test_insert() -> None:
     insert = doctrees['insert']
     new_nodes = list(merge_doctrees(original, insert, is_paragraph))
     uids = [n.uid for n in insert.findall(is_paragraph)]
@@ -100,7 +102,7 @@ def test_insert():
     assert original_uids[1:] == uids[2:]
 
 
-def test_insert_beginning():
+def test_insert_beginning() -> None:
     insert_beginning = doctrees['insert_beginning']
     new_nodes = list(merge_doctrees(original, insert_beginning, is_paragraph))
     uids = [n.uid for n in insert_beginning.findall(is_paragraph)]
@@ -110,7 +112,7 @@ def test_insert_beginning():
     assert original_uids[0] != uids[0]
 
 
-def test_insert_similar():
+def test_insert_similar() -> None:
     insert_similar = doctrees['insert_similar']
     new_nodes = list(merge_doctrees(original, insert_similar, is_paragraph))
     uids = [n.uid for n in insert_similar.findall(is_paragraph)]
